# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/WhisperSpeech',
                'doc_host': 'https://collabora.github.io',
                'git_url': 'https://github.com/collabora/WhisperSpeech',
                'lib_path': 'whisperspeech'},
  'syms': { 'whisperspeech.a2wav': { 'whisperspeech.a2wav.Vocoder': ('6. quality-boosting vocoder.html#vocoder', 'whisperspeech/a2wav.py'),
                                     'whisperspeech.a2wav.Vocoder.__init__': ( '6. quality-boosting vocoder.html#vocoder.__init__',
                                                                               'whisperspeech/a2wav.py'),
                                     'whisperspeech.a2wav.Vocoder.decode': ( '6. quality-boosting vocoder.html#vocoder.decode',
                                                                             'whisperspeech/a2wav.py'),
                                     'whisperspeech.a2wav.Vocoder.decode_to_file': ( '6. quality-boosting '
                                                                                     'vocoder.html#vocoder.decode_to_file',
                                                                                     'whisperspeech/a2wav.py'),
                                     'whisperspeech.a2wav.Vocoder.decode_to_notebook': ( '6. quality-boosting '
                                                                                         'vocoder.html#vocoder.decode_to_notebook',
                                                                                         'whisperspeech/a2wav.py')},
            'whisperspeech.extract_acoustic': { 'whisperspeech.extract_acoustic.extract_Atoks': ( '1. acoustic token '
                                                                                                  'extraction.html#extract_atoks',
                                                                                                  'whisperspeech/extract_acoustic.py'),
                                                'whisperspeech.extract_acoustic.extract_acoustic': ( '1. acoustic token '
                                                                                                     'extraction.html#extract_acoustic',
                                                                                                     'whisperspeech/extract_acoustic.py'),
                                                'whisperspeech.extract_acoustic.load': ( '1. acoustic token extraction.html#load',
                                                                                         'whisperspeech/extract_acoustic.py'),
                                                'whisperspeech.extract_acoustic.load_model': ( '1. acoustic token '
                                                                                               'extraction.html#load_model',
                                                                                               'whisperspeech/extract_acoustic.py')},
            'whisperspeech.extract_semb': { 'whisperspeech.extract_semb.encode_semantic': ( '2c. whisper semantic embedding '
                                                                                            'extraction.html#encode_semantic',
                                                                                            'whisperspeech/extract_semb.py'),
                                            'whisperspeech.extract_semb.extract_semantic': ( '2c. whisper semantic embedding '
                                                                                             'extraction.html#extract_semantic',
                                                                                             'whisperspeech/extract_semb.py'),
                                            'whisperspeech.extract_semb.load_model': ( '2c. whisper semantic embedding '
                                                                                       'extraction.html#load_model',
                                                                                       'whisperspeech/extract_semb.py')},
            'whisperspeech.fetch_models': { 'whisperspeech.fetch_models.main': ( '0. download models.html#main',
                                                                                 'whisperspeech/fetch_models.py')},
            'whisperspeech.modules': { 'whisperspeech.modules.Decoder': ('a. neural modules.html#decoder', 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Decoder.__init__': ( 'a. neural modules.html#decoder.__init__',
                                                                                   'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Decoder.forward': ( 'a. neural modules.html#decoder.forward',
                                                                                  'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Encoder': ('a. neural modules.html#encoder', 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Encoder.__init__': ( 'a. neural modules.html#encoder.__init__',
                                                                                   'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Encoder.forward': ( 'a. neural modules.html#encoder.forward',
                                                                                  'whisperspeech/modules.py'),
                                       'whisperspeech.modules.LayerNorm': ('a. neural modules.html#layernorm', 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.LayerNorm.forward': ( 'a. neural modules.html#layernorm.forward',
                                                                                    'whisperspeech/modules.py'),
                                       'whisperspeech.modules.LinearHead': ( 'a. neural modules.html#linearhead',
                                                                             'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention': ( 'a. neural modules.html#multiheadattention',
                                                                                     'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention.__init__': ( 'a. neural '
                                                                                              'modules.html#multiheadattention.__init__',
                                                                                              'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention.forward': ( 'a. neural '
                                                                                             'modules.html#multiheadattention.forward',
                                                                                             'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention.qkv_attention_pth20': ( 'a. neural '
                                                                                                         'modules.html#multiheadattention.qkv_attention_pth20',
                                                                                                         'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention.qkv_attention_vanilla': ( 'a. neural '
                                                                                                           'modules.html#multiheadattention.qkv_attention_vanilla',
                                                                                                           'whisperspeech/modules.py'),
                                       'whisperspeech.modules.MultiHeadAttention.qkv_attention_xformers': ( 'a. neural '
                                                                                                            'modules.html#multiheadattention.qkv_attention_xformers',
                                                                                                            'whisperspeech/modules.py'),
                                       'whisperspeech.modules.QueryHead': ('a. neural modules.html#queryhead', 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.ResidualAttentionBlock': ( 'a. neural modules.html#residualattentionblock',
                                                                                         'whisperspeech/modules.py'),
                                       'whisperspeech.modules.ResidualAttentionBlock.__init__': ( 'a. neural '
                                                                                                  'modules.html#residualattentionblock.__init__',
                                                                                                  'whisperspeech/modules.py'),
                                       'whisperspeech.modules.ResidualAttentionBlock.forward': ( 'a. neural '
                                                                                                 'modules.html#residualattentionblock.forward',
                                                                                                 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Rotary': ('a. neural modules.html#rotary', 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Rotary.__init__': ( 'a. neural modules.html#rotary.__init__',
                                                                                  'whisperspeech/modules.py'),
                                       'whisperspeech.modules.Rotary.forward': ( 'a. neural modules.html#rotary.forward',
                                                                                 'whisperspeech/modules.py'),
                                       'whisperspeech.modules.SumDecoder': ( 'a. neural modules.html#sumdecoder',
                                                                             'whisperspeech/modules.py'),
                                       'whisperspeech.modules.SumDecoder.__init__': ( 'a. neural modules.html#sumdecoder.__init__',
                                                                                      'whisperspeech/modules.py'),
                                       'whisperspeech.modules.SumDecoder.forward': ( 'a. neural modules.html#sumdecoder.forward',
                                                                                     'whisperspeech/modules.py'),
                                       'whisperspeech.modules.apply_rotary_pos_emb': ( 'a. neural modules.html#apply_rotary_pos_emb',
                                                                                       'whisperspeech/modules.py'),
                                       'whisperspeech.modules.init_transformer': ( 'a. neural modules.html#init_transformer',
                                                                                   'whisperspeech/modules.py'),
                                       'whisperspeech.modules.rotate_half': ( 'a. neural modules.html#rotate_half',
                                                                              'whisperspeech/modules.py'),
                                       'whisperspeech.modules.sinusoids': ('a. neural modules.html#sinusoids', 'whisperspeech/modules.py')},
            'whisperspeech.pipeline': { 'whisperspeech.pipeline.Pipeline': ('7. pipeline.html#pipeline', 'whisperspeech/pipeline.py'),
                                        'whisperspeech.pipeline.Pipeline.__init__': ( '7. pipeline.html#pipeline.__init__',
                                                                                      'whisperspeech/pipeline.py'),
                                        'whisperspeech.pipeline.Pipeline.generate': ( '7. pipeline.html#pipeline.generate',
                                                                                      'whisperspeech/pipeline.py'),
                                        'whisperspeech.pipeline.Pipeline.generate_atoks': ( '7. pipeline.html#pipeline.generate_atoks',
                                                                                            'whisperspeech/pipeline.py'),
                                        'whisperspeech.pipeline.Pipeline.generate_to_file': ( '7. pipeline.html#pipeline.generate_to_file',
                                                                                              'whisperspeech/pipeline.py'),
                                        'whisperspeech.pipeline.Pipeline.generate_to_notebook': ( '7. '
                                                                                                  'pipeline.html#pipeline.generate_to_notebook',
                                                                                                  'whisperspeech/pipeline.py')},
            'whisperspeech.prepare_s2a_dataset': { 'whisperspeech.prepare_s2a_dataset.flac_to_s2a_name': ( '4a. s2a dataset '
                                                                                                           'preparation.html#flac_to_s2a_name',
                                                                                                           'whisperspeech/prepare_s2a_dataset.py'),
                                                   'whisperspeech.prepare_s2a_dataset.prepare_s2a': ( '4a. s2a dataset '
                                                                                                      'preparation.html#prepare_s2a',
                                                                                                      'whisperspeech/prepare_s2a_dataset.py'),
                                                   'whisperspeech.prepare_s2a_dataset.resampler': ( '4a. s2a dataset '
                                                                                                    'preparation.html#resampler',
                                                                                                    'whisperspeech/prepare_s2a_dataset.py')},
            'whisperspeech.prepare_t2s_dataset': { 'whisperspeech.prepare_t2s_dataset.Transcriber': ( '5a. t2s dataset '
                                                                                                      'preparation.html#transcriber',
                                                                                                      'whisperspeech/prepare_t2s_dataset.py'),
                                                   'whisperspeech.prepare_t2s_dataset.Transcriber.__init__': ( '5a. t2s dataset '
                                                                                                               'preparation.html#transcriber.__init__',
                                                                                                               'whisperspeech/prepare_t2s_dataset.py'),
                                                   'whisperspeech.prepare_t2s_dataset.Transcriber.transcribe': ( '5a. t2s dataset '
                                                                                                                 'preparation.html#transcriber.transcribe',
                                                                                                                 'whisperspeech/prepare_t2s_dataset.py'),
                                                   'whisperspeech.prepare_t2s_dataset.flac_to_t2s_name': ( '5a. t2s dataset '
                                                                                                           'preparation.html#flac_to_t2s_name',
                                                                                                           'whisperspeech/prepare_t2s_dataset.py'),
                                                   'whisperspeech.prepare_t2s_dataset.prepare_t2s': ( '5a. t2s dataset '
                                                                                                      'preparation.html#prepare_t2s',
                                                                                                      'whisperspeech/prepare_t2s_dataset.py')},
            'whisperspeech.s2a_delar_mup': { 'whisperspeech.s2a_delar_mup.CMLMVisual': ( '3c. multi-speaker semantic to acoustic token '
                                                                                         'modeling musicgen μpt pitch.html#cmlmvisual',
                                                                                         'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.__init__': ( '3c. multi-speaker semantic to acoustic '
                                                                                                  'token modeling musicgen μpt '
                                                                                                  'pitch.html#cmlmvisual.__init__',
                                                                                                  'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.add_data': ( '3c. multi-speaker semantic to acoustic '
                                                                                                  'token modeling musicgen μpt '
                                                                                                  'pitch.html#cmlmvisual.add_data',
                                                                                                  'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.add_table_row': ( '3c. multi-speaker semantic to '
                                                                                                       'acoustic token modeling musicgen '
                                                                                                       'μpt '
                                                                                                       'pitch.html#cmlmvisual.add_table_row',
                                                                                                       'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.hide': ( '3c. multi-speaker semantic to acoustic '
                                                                                              'token modeling musicgen μpt '
                                                                                              'pitch.html#cmlmvisual.hide',
                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.on_iter': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#cmlmvisual.on_iter',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.plot': ( '3c. multi-speaker semantic to acoustic '
                                                                                              'token modeling musicgen μpt '
                                                                                              'pitch.html#cmlmvisual.plot',
                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.CMLMVisual.show': ( '3c. multi-speaker semantic to acoustic '
                                                                                              'token modeling musicgen μpt '
                                                                                              'pitch.html#cmlmvisual.show',
                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.DelSumDecoder': ( '3c. multi-speaker semantic to acoustic token '
                                                                                            'modeling musicgen μpt '
                                                                                            'pitch.html#delsumdecoder',
                                                                                            'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.DelSumDecoder.__init__': ( '3c. multi-speaker semantic to '
                                                                                                     'acoustic token modeling musicgen μpt '
                                                                                                     'pitch.html#delsumdecoder.__init__',
                                                                                                     'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.DelSumDecoder.forward': ( '3c. multi-speaker semantic to '
                                                                                                    'acoustic token modeling musicgen μpt '
                                                                                                    'pitch.html#delsumdecoder.forward',
                                                                                                    'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.MultiHeadAttention': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#multiheadattention',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.MultiHeadAttention.__init__': ( '3c. multi-speaker semantic to '
                                                                                                          'acoustic token modeling '
                                                                                                          'musicgen μpt '
                                                                                                          'pitch.html#multiheadattention.__init__',
                                                                                                          'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.MultiHeadAttention.forward': ( '3c. multi-speaker semantic to '
                                                                                                         'acoustic token modeling musicgen '
                                                                                                         'μpt '
                                                                                                         'pitch.html#multiheadattention.forward',
                                                                                                         'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.MultiHeadAttention.qkv_attention_pth20': ( '3c. multi-speaker '
                                                                                                                     'semantic to acoustic '
                                                                                                                     'token modeling '
                                                                                                                     'musicgen μpt '
                                                                                                                     'pitch.html#multiheadattention.qkv_attention_pth20',
                                                                                                                     'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.MultiHeadAttention.qkv_attention_xformers': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'pitch.html#multiheadattention.qkv_attention_xformers',
                                                                                                                        'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.ResidualAttentionBlock': ( '3c. multi-speaker semantic to '
                                                                                                     'acoustic token modeling musicgen μpt '
                                                                                                     'pitch.html#residualattentionblock',
                                                                                                     'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.ResidualAttentionBlock.__init__': ( '3c. multi-speaker semantic '
                                                                                                              'to acoustic token modeling '
                                                                                                              'musicgen μpt '
                                                                                                              'pitch.html#residualattentionblock.__init__',
                                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.ResidualAttentionBlock.forward': ( '3c. multi-speaker semantic '
                                                                                                             'to acoustic token modeling '
                                                                                                             'musicgen μpt '
                                                                                                             'pitch.html#residualattentionblock.forward',
                                                                                                             'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.Rotary': ( '3c. multi-speaker semantic to acoustic token '
                                                                                     'modeling musicgen μpt pitch.html#rotary',
                                                                                     'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.Rotary.__init__': ( '3c. multi-speaker semantic to acoustic '
                                                                                              'token modeling musicgen μpt '
                                                                                              'pitch.html#rotary.__init__',
                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.Rotary.forward': ( '3c. multi-speaker semantic to acoustic token '
                                                                                             'modeling musicgen μpt '
                                                                                             'pitch.html#rotary.forward',
                                                                                             'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset': ( '3c. multi-speaker semantic to acoustic token '
                                                                                        'modeling musicgen μpt pitch.html#sadataset',
                                                                                        'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.S_tokens': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#sadataset.s_tokens',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.__getitem__': ( '3c. multi-speaker semantic to '
                                                                                                    'acoustic token modeling musicgen μpt '
                                                                                                    'pitch.html#sadataset.__getitem__',
                                                                                                    'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.__init__': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#sadataset.__init__',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.__len__': ( '3c. multi-speaker semantic to acoustic '
                                                                                                'token modeling musicgen μpt '
                                                                                                'pitch.html#sadataset.__len__',
                                                                                                'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.__repr__': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#sadataset.__repr__',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADataset.hours': ( '3c. multi-speaker semantic to acoustic '
                                                                                              'token modeling musicgen μpt '
                                                                                              'pitch.html#sadataset.hours',
                                                                                              'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'pitch.html#sadelartransformer',
                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.__init__': ( '3c. multi-speaker semantic to '
                                                                                                          'acoustic token modeling '
                                                                                                          'musicgen μpt '
                                                                                                          'pitch.html#sadelartransformer.__init__',
                                                                                                          'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.device': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt '
                                                                                                        'pitch.html#sadelartransformer.device',
                                                                                                        'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.embed_stoks': ( '3c. multi-speaker semantic '
                                                                                                             'to acoustic token modeling '
                                                                                                             'musicgen μpt '
                                                                                                             'pitch.html#sadelartransformer.embed_stoks',
                                                                                                             'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.forward': ( '3c. multi-speaker semantic to '
                                                                                                         'acoustic token modeling musicgen '
                                                                                                         'μpt '
                                                                                                         'pitch.html#sadelartransformer.forward',
                                                                                                         'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.generate': ( '3c. multi-speaker semantic to '
                                                                                                          'acoustic token modeling '
                                                                                                          'musicgen μpt '
                                                                                                          'pitch.html#sadelartransformer.generate',
                                                                                                          'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.init_transformer': ( '3c. multi-speaker '
                                                                                                                  'semantic to acoustic '
                                                                                                                  'token modeling musicgen '
                                                                                                                  'μpt '
                                                                                                                  'pitch.html#sadelartransformer.init_transformer',
                                                                                                                  'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.load_checkpoint': ( '3c. multi-speaker '
                                                                                                                 'semantic to acoustic '
                                                                                                                 'token modeling musicgen '
                                                                                                                 'μpt '
                                                                                                                 'pitch.html#sadelartransformer.load_checkpoint',
                                                                                                                 'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.load_model': ( '3c. multi-speaker semantic to '
                                                                                                            'acoustic token modeling '
                                                                                                            'musicgen μpt '
                                                                                                            'pitch.html#sadelartransformer.load_model',
                                                                                                            'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.reset_stats': ( '3c. multi-speaker semantic '
                                                                                                             'to acoustic token modeling '
                                                                                                             'musicgen μpt '
                                                                                                             'pitch.html#sadelartransformer.reset_stats',
                                                                                                             'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.SADelARTransformer.save_model': ( '3c. multi-speaker semantic to '
                                                                                                            'acoustic token modeling '
                                                                                                            'musicgen μpt '
                                                                                                            'pitch.html#sadelartransformer.save_model',
                                                                                                            'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.Tunables': ( '3c. multi-speaker semantic to acoustic token '
                                                                                       'modeling musicgen μpt pitch.html#tunables',
                                                                                       'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.Tunables.__post_init__': ( '3c. multi-speaker semantic to '
                                                                                                     'acoustic token modeling musicgen μpt '
                                                                                                     'pitch.html#tunables.__post_init__',
                                                                                                     'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.apply_rotary_pos_emb': ( '3c. multi-speaker semantic to acoustic '
                                                                                                   'token modeling musicgen μpt '
                                                                                                   'pitch.html#apply_rotary_pos_emb',
                                                                                                   'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.load_datasets': ( '3c. multi-speaker semantic to acoustic token '
                                                                                            'modeling musicgen μpt '
                                                                                            'pitch.html#load_datasets',
                                                                                            'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.make_model': ( '3c. multi-speaker semantic to acoustic token '
                                                                                         'modeling musicgen μpt pitch.html#make_model',
                                                                                         'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.rand': ( '3c. multi-speaker semantic to acoustic token modeling '
                                                                                   'musicgen μpt pitch.html#rand',
                                                                                   'whisperspeech/s2a_delar_mup.py'),
                                             'whisperspeech.s2a_delar_mup.rotate_half': ( '3c. multi-speaker semantic to acoustic token '
                                                                                          'modeling musicgen μpt pitch.html#rotate_half',
                                                                                          'whisperspeech/s2a_delar_mup.py')},
            'whisperspeech.s2a_delar_mup_cut_semantic': { 'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual': ( '3c. multi-speaker '
                                                                                                                   'semantic to acoustic '
                                                                                                                   'token modeling '
                                                                                                                   'musicgen μpt '
                                                                                                                   'cut-semantic.html#cmlmvisual',
                                                                                                                   'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.__init__': ( '3c. '
                                                                                                                            'multi-speaker '
                                                                                                                            'semantic to '
                                                                                                                            'acoustic '
                                                                                                                            'token '
                                                                                                                            'modeling '
                                                                                                                            'musicgen μpt '
                                                                                                                            'cut-semantic.html#cmlmvisual.__init__',
                                                                                                                            'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.add_data': ( '3c. '
                                                                                                                            'multi-speaker '
                                                                                                                            'semantic to '
                                                                                                                            'acoustic '
                                                                                                                            'token '
                                                                                                                            'modeling '
                                                                                                                            'musicgen μpt '
                                                                                                                            'cut-semantic.html#cmlmvisual.add_data',
                                                                                                                            'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.add_table_row': ( '3c. '
                                                                                                                                 'multi-speaker '
                                                                                                                                 'semantic '
                                                                                                                                 'to '
                                                                                                                                 'acoustic '
                                                                                                                                 'token '
                                                                                                                                 'modeling '
                                                                                                                                 'musicgen '
                                                                                                                                 'μpt '
                                                                                                                                 'cut-semantic.html#cmlmvisual.add_table_row',
                                                                                                                                 'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.hide': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'cut-semantic.html#cmlmvisual.hide',
                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.on_iter': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#cmlmvisual.on_iter',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.plot': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'cut-semantic.html#cmlmvisual.plot',
                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.CMLMVisual.show': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'cut-semantic.html#cmlmvisual.show',
                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.DelSumDecoder': ( '3c. multi-speaker '
                                                                                                                      'semantic to '
                                                                                                                      'acoustic token '
                                                                                                                      'modeling musicgen '
                                                                                                                      'μpt '
                                                                                                                      'cut-semantic.html#delsumdecoder',
                                                                                                                      'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.DelSumDecoder.__init__': ( '3c. '
                                                                                                                               'multi-speaker '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'token '
                                                                                                                               'modeling '
                                                                                                                               'musicgen '
                                                                                                                               'μpt '
                                                                                                                               'cut-semantic.html#delsumdecoder.__init__',
                                                                                                                               'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.DelSumDecoder.forward': ( '3c. '
                                                                                                                              'multi-speaker '
                                                                                                                              'semantic to '
                                                                                                                              'acoustic '
                                                                                                                              'token '
                                                                                                                              'modeling '
                                                                                                                              'musicgen '
                                                                                                                              'μpt '
                                                                                                                              'cut-semantic.html#delsumdecoder.forward',
                                                                                                                              'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.MultiHeadAttention': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#multiheadattention',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.MultiHeadAttention.__init__': ( '3c. '
                                                                                                                                    'multi-speaker '
                                                                                                                                    'semantic '
                                                                                                                                    'to '
                                                                                                                                    'acoustic '
                                                                                                                                    'token '
                                                                                                                                    'modeling '
                                                                                                                                    'musicgen '
                                                                                                                                    'μpt '
                                                                                                                                    'cut-semantic.html#multiheadattention.__init__',
                                                                                                                                    'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.MultiHeadAttention.forward': ( '3c. '
                                                                                                                                   'multi-speaker '
                                                                                                                                   'semantic '
                                                                                                                                   'to '
                                                                                                                                   'acoustic '
                                                                                                                                   'token '
                                                                                                                                   'modeling '
                                                                                                                                   'musicgen '
                                                                                                                                   'μpt '
                                                                                                                                   'cut-semantic.html#multiheadattention.forward',
                                                                                                                                   'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.MultiHeadAttention.qkv_attention_pth20': ( '3c. '
                                                                                                                                               'multi-speaker '
                                                                                                                                               'semantic '
                                                                                                                                               'to '
                                                                                                                                               'acoustic '
                                                                                                                                               'token '
                                                                                                                                               'modeling '
                                                                                                                                               'musicgen '
                                                                                                                                               'μpt '
                                                                                                                                               'cut-semantic.html#multiheadattention.qkv_attention_pth20',
                                                                                                                                               'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.MultiHeadAttention.qkv_attention_xformers': ( '3c. '
                                                                                                                                                  'multi-speaker '
                                                                                                                                                  'semantic '
                                                                                                                                                  'to '
                                                                                                                                                  'acoustic '
                                                                                                                                                  'token '
                                                                                                                                                  'modeling '
                                                                                                                                                  'musicgen '
                                                                                                                                                  'μpt '
                                                                                                                                                  'cut-semantic.html#multiheadattention.qkv_attention_xformers',
                                                                                                                                                  'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.ResidualAttentionBlock': ( '3c. '
                                                                                                                               'multi-speaker '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'token '
                                                                                                                               'modeling '
                                                                                                                               'musicgen '
                                                                                                                               'μpt '
                                                                                                                               'cut-semantic.html#residualattentionblock',
                                                                                                                               'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.ResidualAttentionBlock.__init__': ( '3c. '
                                                                                                                                        'multi-speaker '
                                                                                                                                        'semantic '
                                                                                                                                        'to '
                                                                                                                                        'acoustic '
                                                                                                                                        'token '
                                                                                                                                        'modeling '
                                                                                                                                        'musicgen '
                                                                                                                                        'μpt '
                                                                                                                                        'cut-semantic.html#residualattentionblock.__init__',
                                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.ResidualAttentionBlock.forward': ( '3c. '
                                                                                                                                       'multi-speaker '
                                                                                                                                       'semantic '
                                                                                                                                       'to '
                                                                                                                                       'acoustic '
                                                                                                                                       'token '
                                                                                                                                       'modeling '
                                                                                                                                       'musicgen '
                                                                                                                                       'μpt '
                                                                                                                                       'cut-semantic.html#residualattentionblock.forward',
                                                                                                                                       'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Rotary': ( '3c. multi-speaker semantic '
                                                                                                               'to acoustic token modeling '
                                                                                                               'musicgen μpt '
                                                                                                               'cut-semantic.html#rotary',
                                                                                                               'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Rotary.__init__': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'cut-semantic.html#rotary.__init__',
                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Rotary.forward': ( '3c. multi-speaker '
                                                                                                                       'semantic to '
                                                                                                                       'acoustic token '
                                                                                                                       'modeling musicgen '
                                                                                                                       'μpt '
                                                                                                                       'cut-semantic.html#rotary.forward',
                                                                                                                       'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset': ( '3c. multi-speaker '
                                                                                                                  'semantic to acoustic '
                                                                                                                  'token modeling musicgen '
                                                                                                                  'μpt '
                                                                                                                  'cut-semantic.html#sadataset',
                                                                                                                  'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.S_tokens': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#sadataset.s_tokens',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.__getitem__': ( '3c. '
                                                                                                                              'multi-speaker '
                                                                                                                              'semantic to '
                                                                                                                              'acoustic '
                                                                                                                              'token '
                                                                                                                              'modeling '
                                                                                                                              'musicgen '
                                                                                                                              'μpt '
                                                                                                                              'cut-semantic.html#sadataset.__getitem__',
                                                                                                                              'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.__init__': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#sadataset.__init__',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.__len__': ( '3c. '
                                                                                                                          'multi-speaker '
                                                                                                                          'semantic to '
                                                                                                                          'acoustic token '
                                                                                                                          'modeling '
                                                                                                                          'musicgen μpt '
                                                                                                                          'cut-semantic.html#sadataset.__len__',
                                                                                                                          'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.__repr__': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#sadataset.__repr__',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADataset.hours': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'cut-semantic.html#sadataset.hours',
                                                                                                                        'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'cut-semantic.html#sadelartransformer',
                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.__init__': ( '3c. '
                                                                                                                                    'multi-speaker '
                                                                                                                                    'semantic '
                                                                                                                                    'to '
                                                                                                                                    'acoustic '
                                                                                                                                    'token '
                                                                                                                                    'modeling '
                                                                                                                                    'musicgen '
                                                                                                                                    'μpt '
                                                                                                                                    'cut-semantic.html#sadelartransformer.__init__',
                                                                                                                                    'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.device': ( '3c. '
                                                                                                                                  'multi-speaker '
                                                                                                                                  'semantic '
                                                                                                                                  'to '
                                                                                                                                  'acoustic '
                                                                                                                                  'token '
                                                                                                                                  'modeling '
                                                                                                                                  'musicgen '
                                                                                                                                  'μpt '
                                                                                                                                  'cut-semantic.html#sadelartransformer.device',
                                                                                                                                  'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.embed_stoks': ( '3c. '
                                                                                                                                       'multi-speaker '
                                                                                                                                       'semantic '
                                                                                                                                       'to '
                                                                                                                                       'acoustic '
                                                                                                                                       'token '
                                                                                                                                       'modeling '
                                                                                                                                       'musicgen '
                                                                                                                                       'μpt '
                                                                                                                                       'cut-semantic.html#sadelartransformer.embed_stoks',
                                                                                                                                       'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.forward': ( '3c. '
                                                                                                                                   'multi-speaker '
                                                                                                                                   'semantic '
                                                                                                                                   'to '
                                                                                                                                   'acoustic '
                                                                                                                                   'token '
                                                                                                                                   'modeling '
                                                                                                                                   'musicgen '
                                                                                                                                   'μpt '
                                                                                                                                   'cut-semantic.html#sadelartransformer.forward',
                                                                                                                                   'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.generate': ( '3c. '
                                                                                                                                    'multi-speaker '
                                                                                                                                    'semantic '
                                                                                                                                    'to '
                                                                                                                                    'acoustic '
                                                                                                                                    'token '
                                                                                                                                    'modeling '
                                                                                                                                    'musicgen '
                                                                                                                                    'μpt '
                                                                                                                                    'cut-semantic.html#sadelartransformer.generate',
                                                                                                                                    'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.init_transformer': ( '3c. '
                                                                                                                                            'multi-speaker '
                                                                                                                                            'semantic '
                                                                                                                                            'to '
                                                                                                                                            'acoustic '
                                                                                                                                            'token '
                                                                                                                                            'modeling '
                                                                                                                                            'musicgen '
                                                                                                                                            'μpt '
                                                                                                                                            'cut-semantic.html#sadelartransformer.init_transformer',
                                                                                                                                            'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.load_checkpoint': ( '3c. '
                                                                                                                                           'multi-speaker '
                                                                                                                                           'semantic '
                                                                                                                                           'to '
                                                                                                                                           'acoustic '
                                                                                                                                           'token '
                                                                                                                                           'modeling '
                                                                                                                                           'musicgen '
                                                                                                                                           'μpt '
                                                                                                                                           'cut-semantic.html#sadelartransformer.load_checkpoint',
                                                                                                                                           'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.load_model': ( '3c. '
                                                                                                                                      'multi-speaker '
                                                                                                                                      'semantic '
                                                                                                                                      'to '
                                                                                                                                      'acoustic '
                                                                                                                                      'token '
                                                                                                                                      'modeling '
                                                                                                                                      'musicgen '
                                                                                                                                      'μpt '
                                                                                                                                      'cut-semantic.html#sadelartransformer.load_model',
                                                                                                                                      'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.reset_stats': ( '3c. '
                                                                                                                                       'multi-speaker '
                                                                                                                                       'semantic '
                                                                                                                                       'to '
                                                                                                                                       'acoustic '
                                                                                                                                       'token '
                                                                                                                                       'modeling '
                                                                                                                                       'musicgen '
                                                                                                                                       'μpt '
                                                                                                                                       'cut-semantic.html#sadelartransformer.reset_stats',
                                                                                                                                       'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.SADelARTransformer.save_model': ( '3c. '
                                                                                                                                      'multi-speaker '
                                                                                                                                      'semantic '
                                                                                                                                      'to '
                                                                                                                                      'acoustic '
                                                                                                                                      'token '
                                                                                                                                      'modeling '
                                                                                                                                      'musicgen '
                                                                                                                                      'μpt '
                                                                                                                                      'cut-semantic.html#sadelartransformer.save_model',
                                                                                                                                      'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Tunables': ( '3c. multi-speaker '
                                                                                                                 'semantic to acoustic '
                                                                                                                 'token modeling musicgen '
                                                                                                                 'μpt '
                                                                                                                 'cut-semantic.html#tunables',
                                                                                                                 'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Tunables.__post_init__': ( '3c. '
                                                                                                                               'multi-speaker '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'token '
                                                                                                                               'modeling '
                                                                                                                               'musicgen '
                                                                                                                               'μpt '
                                                                                                                               'cut-semantic.html#tunables.__post_init__',
                                                                                                                               'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.Tunables.upgrade': ( '3c. '
                                                                                                                         'multi-speaker '
                                                                                                                         'semantic to '
                                                                                                                         'acoustic token '
                                                                                                                         'modeling '
                                                                                                                         'musicgen μpt '
                                                                                                                         'cut-semantic.html#tunables.upgrade',
                                                                                                                         'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.apply_rotary_pos_emb': ( '3c. '
                                                                                                                             'multi-speaker '
                                                                                                                             'semantic to '
                                                                                                                             'acoustic '
                                                                                                                             'token '
                                                                                                                             'modeling '
                                                                                                                             'musicgen μpt '
                                                                                                                             'cut-semantic.html#apply_rotary_pos_emb',
                                                                                                                             'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.load_datasets': ( '3c. multi-speaker '
                                                                                                                      'semantic to '
                                                                                                                      'acoustic token '
                                                                                                                      'modeling musicgen '
                                                                                                                      'μpt '
                                                                                                                      'cut-semantic.html#load_datasets',
                                                                                                                      'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.make_model': ( '3c. multi-speaker '
                                                                                                                   'semantic to acoustic '
                                                                                                                   'token modeling '
                                                                                                                   'musicgen μpt '
                                                                                                                   'cut-semantic.html#make_model',
                                                                                                                   'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.rand': ( '3c. multi-speaker semantic '
                                                                                                             'to acoustic token modeling '
                                                                                                             'musicgen μpt '
                                                                                                             'cut-semantic.html#rand',
                                                                                                             'whisperspeech/s2a_delar_mup_cut_semantic.py'),
                                                          'whisperspeech.s2a_delar_mup_cut_semantic.rotate_half': ( '3c. multi-speaker '
                                                                                                                    'semantic to acoustic '
                                                                                                                    'token modeling '
                                                                                                                    'musicgen μpt '
                                                                                                                    'cut-semantic.html#rotate_half',
                                                                                                                    'whisperspeech/s2a_delar_mup_cut_semantic.py')},
            'whisperspeech.s2a_delar_mup_rope': { 'whisperspeech.s2a_delar_mup_rope.CMLMVisual': ( '3c. multi-speaker semantic to acoustic '
                                                                                                   'token modeling musicgen μpt '
                                                                                                   'rope.html#cmlmvisual',
                                                                                                   'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.__init__': ( '3c. multi-speaker semantic to '
                                                                                                            'acoustic token modeling '
                                                                                                            'musicgen μpt '
                                                                                                            'rope.html#cmlmvisual.__init__',
                                                                                                            'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.add_data': ( '3c. multi-speaker semantic to '
                                                                                                            'acoustic token modeling '
                                                                                                            'musicgen μpt '
                                                                                                            'rope.html#cmlmvisual.add_data',
                                                                                                            'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.add_table_row': ( '3c. multi-speaker '
                                                                                                                 'semantic to acoustic '
                                                                                                                 'token modeling musicgen '
                                                                                                                 'μpt '
                                                                                                                 'rope.html#cmlmvisual.add_table_row',
                                                                                                                 'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.hide': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt rope.html#cmlmvisual.hide',
                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.on_iter': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#cmlmvisual.on_iter',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.plot': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt rope.html#cmlmvisual.plot',
                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.CMLMVisual.show': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt rope.html#cmlmvisual.show',
                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.DelSumDecoder': ( '3c. multi-speaker semantic to '
                                                                                                      'acoustic token modeling musicgen '
                                                                                                      'μpt rope.html#delsumdecoder',
                                                                                                      'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.DelSumDecoder.__init__': ( '3c. multi-speaker semantic '
                                                                                                               'to acoustic token modeling '
                                                                                                               'musicgen μpt '
                                                                                                               'rope.html#delsumdecoder.__init__',
                                                                                                               'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.DelSumDecoder.forward': ( '3c. multi-speaker semantic '
                                                                                                              'to acoustic token modeling '
                                                                                                              'musicgen μpt '
                                                                                                              'rope.html#delsumdecoder.forward',
                                                                                                              'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.MultiHeadAttention': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#multiheadattention',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.MultiHeadAttention.__init__': ( '3c. multi-speaker '
                                                                                                                    'semantic to acoustic '
                                                                                                                    'token modeling '
                                                                                                                    'musicgen μpt '
                                                                                                                    'rope.html#multiheadattention.__init__',
                                                                                                                    'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.MultiHeadAttention.forward': ( '3c. multi-speaker '
                                                                                                                   'semantic to acoustic '
                                                                                                                   'token modeling '
                                                                                                                   'musicgen μpt '
                                                                                                                   'rope.html#multiheadattention.forward',
                                                                                                                   'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.MultiHeadAttention.qkv_attention_pth20': ( '3c. '
                                                                                                                               'multi-speaker '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'token '
                                                                                                                               'modeling '
                                                                                                                               'musicgen '
                                                                                                                               'μpt '
                                                                                                                               'rope.html#multiheadattention.qkv_attention_pth20',
                                                                                                                               'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.MultiHeadAttention.qkv_attention_xformers': ( '3c. '
                                                                                                                                  'multi-speaker '
                                                                                                                                  'semantic '
                                                                                                                                  'to '
                                                                                                                                  'acoustic '
                                                                                                                                  'token '
                                                                                                                                  'modeling '
                                                                                                                                  'musicgen '
                                                                                                                                  'μpt '
                                                                                                                                  'rope.html#multiheadattention.qkv_attention_xformers',
                                                                                                                                  'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.ResidualAttentionBlock': ( '3c. multi-speaker semantic '
                                                                                                               'to acoustic token modeling '
                                                                                                               'musicgen μpt '
                                                                                                               'rope.html#residualattentionblock',
                                                                                                               'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.ResidualAttentionBlock.__init__': ( '3c. multi-speaker '
                                                                                                                        'semantic to '
                                                                                                                        'acoustic token '
                                                                                                                        'modeling musicgen '
                                                                                                                        'μpt '
                                                                                                                        'rope.html#residualattentionblock.__init__',
                                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.ResidualAttentionBlock.forward': ( '3c. multi-speaker '
                                                                                                                       'semantic to '
                                                                                                                       'acoustic token '
                                                                                                                       'modeling musicgen '
                                                                                                                       'μpt '
                                                                                                                       'rope.html#residualattentionblock.forward',
                                                                                                                       'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Rotary': ( '3c. multi-speaker semantic to acoustic '
                                                                                               'token modeling musicgen μpt '
                                                                                               'rope.html#rotary',
                                                                                               'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Rotary.__init__': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt rope.html#rotary.__init__',
                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Rotary.forward': ( '3c. multi-speaker semantic to '
                                                                                                       'acoustic token modeling musicgen '
                                                                                                       'μpt rope.html#rotary.forward',
                                                                                                       'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset': ( '3c. multi-speaker semantic to acoustic '
                                                                                                  'token modeling musicgen μpt '
                                                                                                  'rope.html#sadataset',
                                                                                                  'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.S_tokens': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#sadataset.s_tokens',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.__getitem__': ( '3c. multi-speaker semantic '
                                                                                                              'to acoustic token modeling '
                                                                                                              'musicgen μpt '
                                                                                                              'rope.html#sadataset.__getitem__',
                                                                                                              'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.__init__': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#sadataset.__init__',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.__len__': ( '3c. multi-speaker semantic to '
                                                                                                          'acoustic token modeling '
                                                                                                          'musicgen μpt '
                                                                                                          'rope.html#sadataset.__len__',
                                                                                                          'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.__repr__': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#sadataset.__repr__',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADataset.hours': ( '3c. multi-speaker semantic to '
                                                                                                        'acoustic token modeling musicgen '
                                                                                                        'μpt rope.html#sadataset.hours',
                                                                                                        'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer': ( '3c. multi-speaker semantic to '
                                                                                                           'acoustic token modeling '
                                                                                                           'musicgen μpt '
                                                                                                           'rope.html#sadelartransformer',
                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.__init__': ( '3c. multi-speaker '
                                                                                                                    'semantic to acoustic '
                                                                                                                    'token modeling '
                                                                                                                    'musicgen μpt '
                                                                                                                    'rope.html#sadelartransformer.__init__',
                                                                                                                    'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.device': ( '3c. multi-speaker '
                                                                                                                  'semantic to acoustic '
                                                                                                                  'token modeling musicgen '
                                                                                                                  'μpt '
                                                                                                                  'rope.html#sadelartransformer.device',
                                                                                                                  'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.embed_stoks': ( '3c. multi-speaker '
                                                                                                                       'semantic to '
                                                                                                                       'acoustic token '
                                                                                                                       'modeling musicgen '
                                                                                                                       'μpt '
                                                                                                                       'rope.html#sadelartransformer.embed_stoks',
                                                                                                                       'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.forward': ( '3c. multi-speaker '
                                                                                                                   'semantic to acoustic '
                                                                                                                   'token modeling '
                                                                                                                   'musicgen μpt '
                                                                                                                   'rope.html#sadelartransformer.forward',
                                                                                                                   'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.generate': ( '3c. multi-speaker '
                                                                                                                    'semantic to acoustic '
                                                                                                                    'token modeling '
                                                                                                                    'musicgen μpt '
                                                                                                                    'rope.html#sadelartransformer.generate',
                                                                                                                    'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.init_transformer': ( '3c. '
                                                                                                                            'multi-speaker '
                                                                                                                            'semantic to '
                                                                                                                            'acoustic '
                                                                                                                            'token '
                                                                                                                            'modeling '
                                                                                                                            'musicgen μpt '
                                                                                                                            'rope.html#sadelartransformer.init_transformer',
                                                                                                                            'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.load_checkpoint': ( '3c. '
                                                                                                                           'multi-speaker '
                                                                                                                           'semantic to '
                                                                                                                           'acoustic token '
                                                                                                                           'modeling '
                                                                                                                           'musicgen μpt '
                                                                                                                           'rope.html#sadelartransformer.load_checkpoint',
                                                                                                                           'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.load_model': ( '3c. multi-speaker '
                                                                                                                      'semantic to '
                                                                                                                      'acoustic token '
                                                                                                                      'modeling musicgen '
                                                                                                                      'μpt '
                                                                                                                      'rope.html#sadelartransformer.load_model',
                                                                                                                      'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.reset_stats': ( '3c. multi-speaker '
                                                                                                                       'semantic to '
                                                                                                                       'acoustic token '
                                                                                                                       'modeling musicgen '
                                                                                                                       'μpt '
                                                                                                                       'rope.html#sadelartransformer.reset_stats',
                                                                                                                       'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.SADelARTransformer.save_model': ( '3c. multi-speaker '
                                                                                                                      'semantic to '
                                                                                                                      'acoustic token '
                                                                                                                      'modeling musicgen '
                                                                                                                      'μpt '
                                                                                                                      'rope.html#sadelartransformer.save_model',
                                                                                                                      'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Tunables': ( '3c. multi-speaker semantic to acoustic '
                                                                                                 'token modeling musicgen μpt '
                                                                                                 'rope.html#tunables',
                                                                                                 'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Tunables.__post_init__': ( '3c. multi-speaker semantic '
                                                                                                               'to acoustic token modeling '
                                                                                                               'musicgen μpt '
                                                                                                               'rope.html#tunables.__post_init__',
                                                                                                               'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.Tunables.__post_init__fp16': ( '3c. multi-speaker '
                                                                                                                   'semantic to acoustic '
                                                                                                                   'token modeling '
                                                                                                                   'musicgen μpt '
                                                                                                                   'rope.html#tunables.__post_init__fp16',
                                                                                                                   'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.apply_rotary_pos_emb': ( '3c. multi-speaker semantic '
                                                                                                             'to acoustic token modeling '
                                                                                                             'musicgen μpt '
                                                                                                             'rope.html#apply_rotary_pos_emb',
                                                                                                             'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.load_datasets': ( '3c. multi-speaker semantic to '
                                                                                                      'acoustic token modeling musicgen '
                                                                                                      'μpt rope.html#load_datasets',
                                                                                                      'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.make_model': ( '3c. multi-speaker semantic to acoustic '
                                                                                                   'token modeling musicgen μpt '
                                                                                                   'rope.html#make_model',
                                                                                                   'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.rand': ( '3c. multi-speaker semantic to acoustic token '
                                                                                             'modeling musicgen μpt rope.html#rand',
                                                                                             'whisperspeech/s2a_delar_mup_rope.py'),
                                                  'whisperspeech.s2a_delar_mup_rope.rotate_half': ( '3c. multi-speaker semantic to '
                                                                                                    'acoustic token modeling musicgen μpt '
                                                                                                    'rope.html#rotate_half',
                                                                                                    'whisperspeech/s2a_delar_mup_rope.py')},
            'whisperspeech.s2a_delar_mup_wds': { 'whisperspeech.s2a_delar_mup_wds.CMLMVisual': ( '4b. semantic to acoustic token '
                                                                                                 'modeling.html#cmlmvisual',
                                                                                                 'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.__init__': ( '4b. semantic to acoustic token '
                                                                                                          'modeling.html#cmlmvisual.__init__',
                                                                                                          'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.add_data': ( '4b. semantic to acoustic token '
                                                                                                          'modeling.html#cmlmvisual.add_data',
                                                                                                          'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.add_table_row': ( '4b. semantic to acoustic '
                                                                                                               'token '
                                                                                                               'modeling.html#cmlmvisual.add_table_row',
                                                                                                               'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.hide': ( '4b. semantic to acoustic token '
                                                                                                      'modeling.html#cmlmvisual.hide',
                                                                                                      'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.on_iter': ( '4b. semantic to acoustic token '
                                                                                                         'modeling.html#cmlmvisual.on_iter',
                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.plot': ( '4b. semantic to acoustic token '
                                                                                                      'modeling.html#cmlmvisual.plot',
                                                                                                      'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.CMLMVisual.show': ( '4b. semantic to acoustic token '
                                                                                                      'modeling.html#cmlmvisual.show',
                                                                                                      'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.DelSumDecoder': ( '4b. semantic to acoustic token '
                                                                                                    'modeling.html#delsumdecoder',
                                                                                                    'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.DelSumDecoder.__init__': ( '4b. semantic to acoustic '
                                                                                                             'token '
                                                                                                             'modeling.html#delsumdecoder.__init__',
                                                                                                             'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.DelSumDecoder.forward': ( '4b. semantic to acoustic '
                                                                                                            'token '
                                                                                                            'modeling.html#delsumdecoder.forward',
                                                                                                            'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.EmbeddingProjector': ( '4b. semantic to acoustic token '
                                                                                                         'modeling.html#embeddingprojector',
                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.MultiHeadAttention': ( '4b. semantic to acoustic token '
                                                                                                         'modeling.html#multiheadattention',
                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.MultiHeadAttention.__init__': ( '4b. semantic to '
                                                                                                                  'acoustic token '
                                                                                                                  'modeling.html#multiheadattention.__init__',
                                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.MultiHeadAttention.forward': ( '4b. semantic to acoustic '
                                                                                                                 'token '
                                                                                                                 'modeling.html#multiheadattention.forward',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.MultiHeadAttention.qkv_attention_pth20': ( '4b. semantic '
                                                                                                                             'to acoustic '
                                                                                                                             'token '
                                                                                                                             'modeling.html#multiheadattention.qkv_attention_pth20',
                                                                                                                             'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.MultiHeadAttention.qkv_attention_xformers': ( '4b. '
                                                                                                                                'semantic '
                                                                                                                                'to '
                                                                                                                                'acoustic '
                                                                                                                                'token '
                                                                                                                                'modeling.html#multiheadattention.qkv_attention_xformers',
                                                                                                                                'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.ResidualAttentionBlock': ( '4b. semantic to acoustic '
                                                                                                             'token '
                                                                                                             'modeling.html#residualattentionblock',
                                                                                                             'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.ResidualAttentionBlock.__init__': ( '4b. semantic to '
                                                                                                                      'acoustic token '
                                                                                                                      'modeling.html#residualattentionblock.__init__',
                                                                                                                      'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.ResidualAttentionBlock.forward': ( '4b. semantic to '
                                                                                                                     'acoustic token '
                                                                                                                     'modeling.html#residualattentionblock.forward',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Rotary': ( '4b. semantic to acoustic token '
                                                                                             'modeling.html#rotary',
                                                                                             'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Rotary.__init__': ( '4b. semantic to acoustic token '
                                                                                                      'modeling.html#rotary.__init__',
                                                                                                      'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Rotary.forward': ( '4b. semantic to acoustic token '
                                                                                                     'modeling.html#rotary.forward',
                                                                                                     'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer': ( '4b. semantic to acoustic token '
                                                                                                         'modeling.html#sadelartransformer',
                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.__init__': ( '4b. semantic to '
                                                                                                                  'acoustic token '
                                                                                                                  'modeling.html#sadelartransformer.__init__',
                                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.device': ( '4b. semantic to acoustic '
                                                                                                                'token '
                                                                                                                'modeling.html#sadelartransformer.device',
                                                                                                                'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.embed_stoks': ( '4b. semantic to '
                                                                                                                     'acoustic token '
                                                                                                                     'modeling.html#sadelartransformer.embed_stoks',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.forward': ( '4b. semantic to acoustic '
                                                                                                                 'token '
                                                                                                                 'modeling.html#sadelartransformer.forward',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.generate': ( '4b. semantic to '
                                                                                                                  'acoustic token '
                                                                                                                  'modeling.html#sadelartransformer.generate',
                                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.get_extra_state': ( '4b. semantic to '
                                                                                                                         'acoustic token '
                                                                                                                         'modeling.html#sadelartransformer.get_extra_state',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.get_metrics': ( '4b. semantic to '
                                                                                                                     'acoustic token '
                                                                                                                     'modeling.html#sadelartransformer.get_metrics',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.init_transformer': ( '4b. semantic to '
                                                                                                                          'acoustic token '
                                                                                                                          'modeling.html#sadelartransformer.init_transformer',
                                                                                                                          'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.load_checkpoint': ( '4b. semantic to '
                                                                                                                         'acoustic token '
                                                                                                                         'modeling.html#sadelartransformer.load_checkpoint',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.load_frozen_semantic_embeddings': ( '4b. '
                                                                                                                                         'semantic '
                                                                                                                                         'to '
                                                                                                                                         'acoustic '
                                                                                                                                         'token '
                                                                                                                                         'modeling.html#sadelartransformer.load_frozen_semantic_embeddings',
                                                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.load_model': ( '4b. semantic to '
                                                                                                                    'acoustic token '
                                                                                                                    'modeling.html#sadelartransformer.load_model',
                                                                                                                    'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.save_model': ( '4b. semantic to '
                                                                                                                    'acoustic token '
                                                                                                                    'modeling.html#sadelartransformer.save_model',
                                                                                                                    'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.set_extra_state': ( '4b. semantic to '
                                                                                                                         'acoustic token '
                                                                                                                         'modeling.html#sadelartransformer.set_extra_state',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.SADelARTransformer.setup': ( '4b. semantic to acoustic '
                                                                                                               'token '
                                                                                                               'modeling.html#sadelartransformer.setup',
                                                                                                               'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Tunables': ( '4b. semantic to acoustic token '
                                                                                               'modeling.html#tunables',
                                                                                               'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Tunables.__post_init__': ( '4b. semantic to acoustic '
                                                                                                             'token '
                                                                                                             'modeling.html#tunables.__post_init__',
                                                                                                             'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.Tunables.upgrade': ( '4b. semantic to acoustic token '
                                                                                                       'modeling.html#tunables.upgrade',
                                                                                                       'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds._make_model': ( '4b. semantic to acoustic token '
                                                                                                  'modeling.html#_make_model',
                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.apply_rotary_pos_emb': ( '4b. semantic to acoustic token '
                                                                                                           'modeling.html#apply_rotary_pos_emb',
                                                                                                           'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.load_datasets': ( '4b. semantic to acoustic token '
                                                                                                    'modeling.html#load_datasets',
                                                                                                    'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.make_model': ( '4b. semantic to acoustic token '
                                                                                                 'modeling.html#make_model',
                                                                                                 'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.pad_samples': ( '4b. semantic to acoustic token '
                                                                                                  'modeling.html#pad_samples',
                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.rand': ( '4b. semantic to acoustic token '
                                                                                           'modeling.html#rand',
                                                                                           'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.random_trunc': ( '4b. semantic to acoustic token '
                                                                                                   'modeling.html#random_trunc',
                                                                                                   'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.rotate_half': ( '4b. semantic to acoustic token '
                                                                                                  'modeling.html#rotate_half',
                                                                                                  'whisperspeech/s2a_delar_mup_wds.py'),
                                                 'whisperspeech.s2a_delar_mup_wds.speaker_id_extractor': ( '4b. semantic to acoustic token '
                                                                                                           'modeling.html#speaker_id_extractor',
                                                                                                           'whisperspeech/s2a_delar_mup_wds.py')},
            'whisperspeech.s2a_delar_mup_wds_2': { 'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual': ( '3c. semantic to acoustic modeling '
                                                                                                     '2-copy1.html#cmlmvisual',
                                                                                                     'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.__init__': ( '3c. semantic to acoustic '
                                                                                                              'modeling '
                                                                                                              '2-copy1.html#cmlmvisual.__init__',
                                                                                                              'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.add_data': ( '3c. semantic to acoustic '
                                                                                                              'modeling '
                                                                                                              '2-copy1.html#cmlmvisual.add_data',
                                                                                                              'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.add_table_row': ( '3c. semantic to '
                                                                                                                   'acoustic modeling '
                                                                                                                   '2-copy1.html#cmlmvisual.add_table_row',
                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.hide': ( '3c. semantic to acoustic '
                                                                                                          'modeling '
                                                                                                          '2-copy1.html#cmlmvisual.hide',
                                                                                                          'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.on_iter': ( '3c. semantic to acoustic '
                                                                                                             'modeling '
                                                                                                             '2-copy1.html#cmlmvisual.on_iter',
                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.plot': ( '3c. semantic to acoustic '
                                                                                                          'modeling '
                                                                                                          '2-copy1.html#cmlmvisual.plot',
                                                                                                          'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.CMLMVisual.show': ( '3c. semantic to acoustic '
                                                                                                          'modeling '
                                                                                                          '2-copy1.html#cmlmvisual.show',
                                                                                                          'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.DelSumDecoder': ( '3c. semantic to acoustic modeling '
                                                                                                        '2-copy1.html#delsumdecoder',
                                                                                                        'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.DelSumDecoder.__init__': ( '3c. semantic to acoustic '
                                                                                                                 'modeling '
                                                                                                                 '2-copy1.html#delsumdecoder.__init__',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.DelSumDecoder.forward': ( '3c. semantic to acoustic '
                                                                                                                'modeling '
                                                                                                                '2-copy1.html#delsumdecoder.forward',
                                                                                                                'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.EmbeddingProjector': ( '3c. semantic to acoustic '
                                                                                                             'modeling '
                                                                                                             '2-copy1.html#embeddingprojector',
                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.MultiHeadAttention': ( '3c. semantic to acoustic '
                                                                                                             'modeling '
                                                                                                             '2-copy1.html#multiheadattention',
                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.MultiHeadAttention.__init__': ( '3c. semantic to '
                                                                                                                      'acoustic modeling '
                                                                                                                      '2-copy1.html#multiheadattention.__init__',
                                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.MultiHeadAttention.forward': ( '3c. semantic to '
                                                                                                                     'acoustic modeling '
                                                                                                                     '2-copy1.html#multiheadattention.forward',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.MultiHeadAttention.qkv_attention_pth20': ( '3c. '
                                                                                                                                 'semantic '
                                                                                                                                 'to '
                                                                                                                                 'acoustic '
                                                                                                                                 'modeling '
                                                                                                                                 '2-copy1.html#multiheadattention.qkv_attention_pth20',
                                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.MultiHeadAttention.qkv_attention_xformers': ( '3c. '
                                                                                                                                    'semantic '
                                                                                                                                    'to '
                                                                                                                                    'acoustic '
                                                                                                                                    'modeling '
                                                                                                                                    '2-copy1.html#multiheadattention.qkv_attention_xformers',
                                                                                                                                    'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.ResidualAttentionBlock': ( '3c. semantic to acoustic '
                                                                                                                 'modeling '
                                                                                                                 '2-copy1.html#residualattentionblock',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.ResidualAttentionBlock.__init__': ( '3c. semantic to '
                                                                                                                          'acoustic '
                                                                                                                          'modeling '
                                                                                                                          '2-copy1.html#residualattentionblock.__init__',
                                                                                                                          'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.ResidualAttentionBlock.forward': ( '3c. semantic to '
                                                                                                                         'acoustic '
                                                                                                                         'modeling '
                                                                                                                         '2-copy1.html#residualattentionblock.forward',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Rotary': ( '3c. semantic to acoustic modeling '
                                                                                                 '2-copy1.html#rotary',
                                                                                                 'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Rotary.__init__': ( '3c. semantic to acoustic '
                                                                                                          'modeling '
                                                                                                          '2-copy1.html#rotary.__init__',
                                                                                                          'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Rotary.forward': ( '3c. semantic to acoustic '
                                                                                                         'modeling '
                                                                                                         '2-copy1.html#rotary.forward',
                                                                                                         'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer': ( '3c. semantic to acoustic '
                                                                                                             'modeling '
                                                                                                             '2-copy1.html#sadelartransformer',
                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.__init__': ( '3c. semantic to '
                                                                                                                      'acoustic modeling '
                                                                                                                      '2-copy1.html#sadelartransformer.__init__',
                                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.device': ( '3c. semantic to '
                                                                                                                    'acoustic modeling '
                                                                                                                    '2-copy1.html#sadelartransformer.device',
                                                                                                                    'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.embed_stoks': ( '3c. semantic to '
                                                                                                                         'acoustic '
                                                                                                                         'modeling '
                                                                                                                         '2-copy1.html#sadelartransformer.embed_stoks',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.forward': ( '3c. semantic to '
                                                                                                                     'acoustic modeling '
                                                                                                                     '2-copy1.html#sadelartransformer.forward',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.generate': ( '3c. semantic to '
                                                                                                                      'acoustic modeling '
                                                                                                                      '2-copy1.html#sadelartransformer.generate',
                                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.get_extra_state': ( '3c. semantic '
                                                                                                                             'to acoustic '
                                                                                                                             'modeling '
                                                                                                                             '2-copy1.html#sadelartransformer.get_extra_state',
                                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.get_metrics': ( '3c. semantic to '
                                                                                                                         'acoustic '
                                                                                                                         'modeling '
                                                                                                                         '2-copy1.html#sadelartransformer.get_metrics',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.init_transformer': ( '3c. '
                                                                                                                              'semantic to '
                                                                                                                              'acoustic '
                                                                                                                              'modeling '
                                                                                                                              '2-copy1.html#sadelartransformer.init_transformer',
                                                                                                                              'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.load_checkpoint': ( '3c. semantic '
                                                                                                                             'to acoustic '
                                                                                                                             'modeling '
                                                                                                                             '2-copy1.html#sadelartransformer.load_checkpoint',
                                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.load_frozen_semantic_embeddings': ( '3c. '
                                                                                                                                             'semantic '
                                                                                                                                             'to '
                                                                                                                                             'acoustic '
                                                                                                                                             'modeling '
                                                                                                                                             '2-copy1.html#sadelartransformer.load_frozen_semantic_embeddings',
                                                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.load_model': ( '3c. semantic to '
                                                                                                                        'acoustic modeling '
                                                                                                                        '2-copy1.html#sadelartransformer.load_model',
                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.save_model': ( '3c. semantic to '
                                                                                                                        'acoustic modeling '
                                                                                                                        '2-copy1.html#sadelartransformer.save_model',
                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.set_extra_state': ( '3c. semantic '
                                                                                                                             'to acoustic '
                                                                                                                             'modeling '
                                                                                                                             '2-copy1.html#sadelartransformer.set_extra_state',
                                                                                                                             'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.SADelARTransformer.setup': ( '3c. semantic to '
                                                                                                                   'acoustic modeling '
                                                                                                                   '2-copy1.html#sadelartransformer.setup',
                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Tunables': ( '3c. semantic to acoustic modeling '
                                                                                                   '2-copy1.html#tunables',
                                                                                                   'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Tunables.__post_init__': ( '3c. semantic to acoustic '
                                                                                                                 'modeling '
                                                                                                                 '2-copy1.html#tunables.__post_init__',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.Tunables.upgrade': ( '3c. semantic to acoustic '
                                                                                                           'modeling '
                                                                                                           '2-copy1.html#tunables.upgrade',
                                                                                                           'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2._make_model': ( '3c. semantic to acoustic modeling '
                                                                                                      '2-copy1.html#_make_model',
                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.apply_rotary_pos_emb': ( '3c. semantic to acoustic '
                                                                                                               'modeling '
                                                                                                               '2-copy1.html#apply_rotary_pos_emb',
                                                                                                               'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.load_datasets': ( '3c. semantic to acoustic modeling '
                                                                                                        '2-copy1.html#load_datasets',
                                                                                                        'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.make_model': ( '3c. semantic to acoustic modeling '
                                                                                                     '2-copy1.html#make_model',
                                                                                                     'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.pad_samples': ( '3c. semantic to acoustic modeling '
                                                                                                      '2-copy1.html#pad_samples',
                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.rand': ( '3c. semantic to acoustic modeling '
                                                                                               '2-copy1.html#rand',
                                                                                               'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.random_trunc': ( '3c. semantic to acoustic modeling '
                                                                                                       '2-copy1.html#random_trunc',
                                                                                                       'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.rotate_half': ( '3c. semantic to acoustic modeling '
                                                                                                      '2-copy1.html#rotate_half',
                                                                                                      'whisperspeech/s2a_delar_mup_wds_2.py'),
                                                   'whisperspeech.s2a_delar_mup_wds_2.speaker_id_extractor': ( '3c. semantic to acoustic '
                                                                                                               'modeling '
                                                                                                               '2-copy1.html#speaker_id_extractor',
                                                                                                               'whisperspeech/s2a_delar_mup_wds_2.py')},
            'whisperspeech.s2a_delar_mup_wds_2_spkcross': { 'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual': ( '3c. semantic to '
                                                                                                                       'acoustic modeling '
                                                                                                                       'spk_cross.html#cmlmvisual',
                                                                                                                       'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.__init__': ( '3c. '
                                                                                                                                'semantic '
                                                                                                                                'to '
                                                                                                                                'acoustic '
                                                                                                                                'modeling '
                                                                                                                                'spk_cross.html#cmlmvisual.__init__',
                                                                                                                                'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.add_data': ( '3c. '
                                                                                                                                'semantic '
                                                                                                                                'to '
                                                                                                                                'acoustic '
                                                                                                                                'modeling '
                                                                                                                                'spk_cross.html#cmlmvisual.add_data',
                                                                                                                                'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.add_table_row': ( '3c. '
                                                                                                                                     'semantic '
                                                                                                                                     'to '
                                                                                                                                     'acoustic '
                                                                                                                                     'modeling '
                                                                                                                                     'spk_cross.html#cmlmvisual.add_table_row',
                                                                                                                                     'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.hide': ( '3c. semantic '
                                                                                                                            'to acoustic '
                                                                                                                            'modeling '
                                                                                                                            'spk_cross.html#cmlmvisual.hide',
                                                                                                                            'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.on_iter': ( '3c. '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'modeling '
                                                                                                                               'spk_cross.html#cmlmvisual.on_iter',
                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.plot': ( '3c. semantic '
                                                                                                                            'to acoustic '
                                                                                                                            'modeling '
                                                                                                                            'spk_cross.html#cmlmvisual.plot',
                                                                                                                            'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.CMLMVisual.show': ( '3c. semantic '
                                                                                                                            'to acoustic '
                                                                                                                            'modeling '
                                                                                                                            'spk_cross.html#cmlmvisual.show',
                                                                                                                            'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.DelSumDecoder': ( '3c. semantic to '
                                                                                                                          'acoustic '
                                                                                                                          'modeling '
                                                                                                                          'spk_cross.html#delsumdecoder',
                                                                                                                          'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.DelSumDecoder.__init__': ( '3c. '
                                                                                                                                   'semantic '
                                                                                                                                   'to '
                                                                                                                                   'acoustic '
                                                                                                                                   'modeling '
                                                                                                                                   'spk_cross.html#delsumdecoder.__init__',
                                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.DelSumDecoder.forward': ( '3c. '
                                                                                                                                  'semantic '
                                                                                                                                  'to '
                                                                                                                                  'acoustic '
                                                                                                                                  'modeling '
                                                                                                                                  'spk_cross.html#delsumdecoder.forward',
                                                                                                                                  'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.EmbeddingProjector': ( '3c. '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'modeling '
                                                                                                                               'spk_cross.html#embeddingprojector',
                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.MultiHeadAttention': ( '3c. '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'modeling '
                                                                                                                               'spk_cross.html#multiheadattention',
                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.MultiHeadAttention.__init__': ( '3c. '
                                                                                                                                        'semantic '
                                                                                                                                        'to '
                                                                                                                                        'acoustic '
                                                                                                                                        'modeling '
                                                                                                                                        'spk_cross.html#multiheadattention.__init__',
                                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.MultiHeadAttention.forward': ( '3c. '
                                                                                                                                       'semantic '
                                                                                                                                       'to '
                                                                                                                                       'acoustic '
                                                                                                                                       'modeling '
                                                                                                                                       'spk_cross.html#multiheadattention.forward',
                                                                                                                                       'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.MultiHeadAttention.qkv_attention_pth20': ( '3c. '
                                                                                                                                                   'semantic '
                                                                                                                                                   'to '
                                                                                                                                                   'acoustic '
                                                                                                                                                   'modeling '
                                                                                                                                                   'spk_cross.html#multiheadattention.qkv_attention_pth20',
                                                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.MultiHeadAttention.qkv_attention_xformers': ( '3c. '
                                                                                                                                                      'semantic '
                                                                                                                                                      'to '
                                                                                                                                                      'acoustic '
                                                                                                                                                      'modeling '
                                                                                                                                                      'spk_cross.html#multiheadattention.qkv_attention_xformers',
                                                                                                                                                      'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.ResidualAttentionBlock': ( '3c. '
                                                                                                                                   'semantic '
                                                                                                                                   'to '
                                                                                                                                   'acoustic '
                                                                                                                                   'modeling '
                                                                                                                                   'spk_cross.html#residualattentionblock',
                                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.ResidualAttentionBlock.__init__': ( '3c. '
                                                                                                                                            'semantic '
                                                                                                                                            'to '
                                                                                                                                            'acoustic '
                                                                                                                                            'modeling '
                                                                                                                                            'spk_cross.html#residualattentionblock.__init__',
                                                                                                                                            'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.ResidualAttentionBlock.forward': ( '3c. '
                                                                                                                                           'semantic '
                                                                                                                                           'to '
                                                                                                                                           'acoustic '
                                                                                                                                           'modeling '
                                                                                                                                           'spk_cross.html#residualattentionblock.forward',
                                                                                                                                           'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Rotary': ( '3c. semantic to '
                                                                                                                   'acoustic modeling '
                                                                                                                   'spk_cross.html#rotary',
                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Rotary.__init__': ( '3c. semantic '
                                                                                                                            'to acoustic '
                                                                                                                            'modeling '
                                                                                                                            'spk_cross.html#rotary.__init__',
                                                                                                                            'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Rotary.forward': ( '3c. semantic '
                                                                                                                           'to acoustic '
                                                                                                                           'modeling '
                                                                                                                           'spk_cross.html#rotary.forward',
                                                                                                                           'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer': ( '3c. '
                                                                                                                               'semantic '
                                                                                                                               'to '
                                                                                                                               'acoustic '
                                                                                                                               'modeling '
                                                                                                                               'spk_cross.html#sadelartransformer',
                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.__init__': ( '3c. '
                                                                                                                                        'semantic '
                                                                                                                                        'to '
                                                                                                                                        'acoustic '
                                                                                                                                        'modeling '
                                                                                                                                        'spk_cross.html#sadelartransformer.__init__',
                                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.device': ( '3c. '
                                                                                                                                      'semantic '
                                                                                                                                      'to '
                                                                                                                                      'acoustic '
                                                                                                                                      'modeling '
                                                                                                                                      'spk_cross.html#sadelartransformer.device',
                                                                                                                                      'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.embed_stoks': ( '3c. '
                                                                                                                                           'semantic '
                                                                                                                                           'to '
                                                                                                                                           'acoustic '
                                                                                                                                           'modeling '
                                                                                                                                           'spk_cross.html#sadelartransformer.embed_stoks',
                                                                                                                                           'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.forward': ( '3c. '
                                                                                                                                       'semantic '
                                                                                                                                       'to '
                                                                                                                                       'acoustic '
                                                                                                                                       'modeling '
                                                                                                                                       'spk_cross.html#sadelartransformer.forward',
                                                                                                                                       'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.generate': ( '3c. '
                                                                                                                                        'semantic '
                                                                                                                                        'to '
                                                                                                                                        'acoustic '
                                                                                                                                        'modeling '
                                                                                                                                        'spk_cross.html#sadelartransformer.generate',
                                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.get_metrics': ( '3c. '
                                                                                                                                           'semantic '
                                                                                                                                           'to '
                                                                                                                                           'acoustic '
                                                                                                                                           'modeling '
                                                                                                                                           'spk_cross.html#sadelartransformer.get_metrics',
                                                                                                                                           'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.init_transformer': ( '3c. '
                                                                                                                                                'semantic '
                                                                                                                                                'to '
                                                                                                                                                'acoustic '
                                                                                                                                                'modeling '
                                                                                                                                                'spk_cross.html#sadelartransformer.init_transformer',
                                                                                                                                                'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.load_checkpoint': ( '3c. '
                                                                                                                                               'semantic '
                                                                                                                                               'to '
                                                                                                                                               'acoustic '
                                                                                                                                               'modeling '
                                                                                                                                               'spk_cross.html#sadelartransformer.load_checkpoint',
                                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.load_frozen_semantic_embeddings': ( '3c. '
                                                                                                                                                               'semantic '
                                                                                                                                                               'to '
                                                                                                                                                               'acoustic '
                                                                                                                                                               'modeling '
                                                                                                                                                               'spk_cross.html#sadelartransformer.load_frozen_semantic_embeddings',
                                                                                                                                                               'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.load_model': ( '3c. '
                                                                                                                                          'semantic '
                                                                                                                                          'to '
                                                                                                                                          'acoustic '
                                                                                                                                          'modeling '
                                                                                                                                          'spk_cross.html#sadelartransformer.load_model',
                                                                                                                                          'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.save_model': ( '3c. '
                                                                                                                                          'semantic '
                                                                                                                                          'to '
                                                                                                                                          'acoustic '
                                                                                                                                          'modeling '
                                                                                                                                          'spk_cross.html#sadelartransformer.save_model',
                                                                                                                                          'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.SADelARTransformer.setup': ( '3c. '
                                                                                                                                     'semantic '
                                                                                                                                     'to '
                                                                                                                                     'acoustic '
                                                                                                                                     'modeling '
                                                                                                                                     'spk_cross.html#sadelartransformer.setup',
                                                                                                                                     'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Tunables': ( '3c. semantic to '
                                                                                                                     'acoustic modeling '
                                                                                                                     'spk_cross.html#tunables',
                                                                                                                     'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Tunables.__post_init__': ( '3c. '
                                                                                                                                   'semantic '
                                                                                                                                   'to '
                                                                                                                                   'acoustic '
                                                                                                                                   'modeling '
                                                                                                                                   'spk_cross.html#tunables.__post_init__',
                                                                                                                                   'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.Tunables.upgrade': ( '3c. semantic '
                                                                                                                             'to acoustic '
                                                                                                                             'modeling '
                                                                                                                             'spk_cross.html#tunables.upgrade',
                                                                                                                             'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross._make_model': ( '3c. semantic to '
                                                                                                                        'acoustic modeling '
                                                                                                                        'spk_cross.html#_make_model',
                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.apply_rotary_pos_emb': ( '3c. '
                                                                                                                                 'semantic '
                                                                                                                                 'to '
                                                                                                                                 'acoustic '
                                                                                                                                 'modeling '
                                                                                                                                 'spk_cross.html#apply_rotary_pos_emb',
                                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.load_datasets': ( '3c. semantic to '
                                                                                                                          'acoustic '
                                                                                                                          'modeling '
                                                                                                                          'spk_cross.html#load_datasets',
                                                                                                                          'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.make_model': ( '3c. semantic to '
                                                                                                                       'acoustic modeling '
                                                                                                                       'spk_cross.html#make_model',
                                                                                                                       'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.pad_samples': ( '3c. semantic to '
                                                                                                                        'acoustic modeling '
                                                                                                                        'spk_cross.html#pad_samples',
                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.rand': ( '3c. semantic to acoustic '
                                                                                                                 'modeling '
                                                                                                                 'spk_cross.html#rand',
                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.random_trunc': ( '3c. semantic to '
                                                                                                                         'acoustic '
                                                                                                                         'modeling '
                                                                                                                         'spk_cross.html#random_trunc',
                                                                                                                         'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.rotate_half': ( '3c. semantic to '
                                                                                                                        'acoustic modeling '
                                                                                                                        'spk_cross.html#rotate_half',
                                                                                                                        'whisperspeech/s2a_delar_mup_wds_2_spkcross.py'),
                                                            'whisperspeech.s2a_delar_mup_wds_2_spkcross.speaker_id_extractor': ( '3c. '
                                                                                                                                 'semantic '
                                                                                                                                 'to '
                                                                                                                                 'acoustic '
                                                                                                                                 'modeling '
                                                                                                                                 'spk_cross.html#speaker_id_extractor',
                                                                                                                                 'whisperspeech/s2a_delar_mup_wds_2_spkcross.py')},
            'whisperspeech.s2a_eval': {},
            'whisperspeech.t2s_up': { 'whisperspeech.t2s_up.Decoder': ( '5. text to semantic token modeling μp old.html#decoder',
                                                                        'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Decoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                 'old.html#decoder.__init__',
                                                                                 'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Decoder.forward': ( '5. text to semantic token modeling μp '
                                                                                'old.html#decoder.forward',
                                                                                'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Encoder': ( '5. text to semantic token modeling μp old.html#encoder',
                                                                        'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Encoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                 'old.html#encoder.__init__',
                                                                                 'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Encoder.forward': ( '5. text to semantic token modeling μp '
                                                                                'old.html#encoder.forward',
                                                                                'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.SADataset': ( '5. text to semantic token modeling μp old.html#sadataset',
                                                                          'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.SADataset.__getitem__': ( '5. text to semantic token modeling μp '
                                                                                      'old.html#sadataset.__getitem__',
                                                                                      'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.SADataset.__init__': ( '5. text to semantic token modeling μp '
                                                                                   'old.html#sadataset.__init__',
                                                                                   'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.SADataset.__len__': ( '5. text to semantic token modeling μp '
                                                                                  'old.html#sadataset.__len__',
                                                                                  'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.SADataset.__repr__': ( '5. text to semantic token modeling μp '
                                                                                   'old.html#sadataset.__repr__',
                                                                                   'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer': ( '5. text to semantic token modeling μp '
                                                                                'old.html#tsartransformer',
                                                                                'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.__init__': ( '5. text to semantic token modeling μp '
                                                                                         'old.html#tsartransformer.__init__',
                                                                                         'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.device': ( '5. text to semantic token modeling μp '
                                                                                       'old.html#tsartransformer.device',
                                                                                       'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.ensure_tokenizer': ( '5. text to semantic token modeling μp '
                                                                                                 'old.html#tsartransformer.ensure_tokenizer',
                                                                                                 'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.forward': ( '5. text to semantic token modeling μp '
                                                                                        'old.html#tsartransformer.forward',
                                                                                        'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.generate': ( '5. text to semantic token modeling μp '
                                                                                         'old.html#tsartransformer.generate',
                                                                                         'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.init_transformer': ( '5. text to semantic token modeling μp '
                                                                                                 'old.html#tsartransformer.init_transformer',
                                                                                                 'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.load_checkpoint': ( '5. text to semantic token modeling μp '
                                                                                                'old.html#tsartransformer.load_checkpoint',
                                                                                                'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.load_model': ( '5. text to semantic token modeling μp '
                                                                                           'old.html#tsartransformer.load_model',
                                                                                           'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.TSARTransformer.save_model': ( '5. text to semantic token modeling μp '
                                                                                           'old.html#tsartransformer.save_model',
                                                                                           'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Tunables': ( '5. text to semantic token modeling μp old.html#tunables',
                                                                         'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.Tunables.__post_init__': ( '5. text to semantic token modeling μp '
                                                                                       'old.html#tunables.__post_init__',
                                                                                       'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.load_data': ( '5. text to semantic token modeling μp old.html#load_data',
                                                                          'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.load_datasets': ( '5. text to semantic token modeling μp '
                                                                              'old.html#load_datasets',
                                                                              'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.make_model': ( '5. text to semantic token modeling μp old.html#make_model',
                                                                           'whisperspeech/t2s_up.py'),
                                      'whisperspeech.t2s_up.rand': ( '5. text to semantic token modeling μp old.html#rand',
                                                                     'whisperspeech/t2s_up.py')},
            'whisperspeech.t2s_up_tests': { 'whisperspeech.t2s_up_tests.Decoder': ( '5. text to semantic token modeling '
                                                                                    'μp-copy1.html#decoder',
                                                                                    'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Decoder.__init__': ( '5. text to semantic token modeling '
                                                                                             'μp-copy1.html#decoder.__init__',
                                                                                             'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Decoder.forward': ( '5. text to semantic token modeling '
                                                                                            'μp-copy1.html#decoder.forward',
                                                                                            'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Encoder': ( '5. text to semantic token modeling '
                                                                                    'μp-copy1.html#encoder',
                                                                                    'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Encoder.__init__': ( '5. text to semantic token modeling '
                                                                                             'μp-copy1.html#encoder.__init__',
                                                                                             'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Encoder.forward': ( '5. text to semantic token modeling '
                                                                                            'μp-copy1.html#encoder.forward',
                                                                                            'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.SADataset': ( '5. text to semantic token modeling '
                                                                                      'μp-copy1.html#sadataset',
                                                                                      'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.SADataset.__getitem__': ( '5. text to semantic token modeling '
                                                                                                  'μp-copy1.html#sadataset.__getitem__',
                                                                                                  'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.SADataset.__init__': ( '5. text to semantic token modeling '
                                                                                               'μp-copy1.html#sadataset.__init__',
                                                                                               'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.SADataset.__len__': ( '5. text to semantic token modeling '
                                                                                              'μp-copy1.html#sadataset.__len__',
                                                                                              'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.SADataset.__repr__': ( '5. text to semantic token modeling '
                                                                                               'μp-copy1.html#sadataset.__repr__',
                                                                                               'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer': ( '5. text to semantic token modeling '
                                                                                            'μp-copy1.html#tsartransformer',
                                                                                            'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.__init__': ( '5. text to semantic token modeling '
                                                                                                     'μp-copy1.html#tsartransformer.__init__',
                                                                                                     'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.device': ( '5. text to semantic token modeling '
                                                                                                   'μp-copy1.html#tsartransformer.device',
                                                                                                   'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.ensure_tokenizer': ( '5. text to semantic token '
                                                                                                             'modeling '
                                                                                                             'μp-copy1.html#tsartransformer.ensure_tokenizer',
                                                                                                             'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.forward': ( '5. text to semantic token modeling '
                                                                                                    'μp-copy1.html#tsartransformer.forward',
                                                                                                    'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.generate': ( '5. text to semantic token modeling '
                                                                                                     'μp-copy1.html#tsartransformer.generate',
                                                                                                     'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.init_transformer': ( '5. text to semantic token '
                                                                                                             'modeling '
                                                                                                             'μp-copy1.html#tsartransformer.init_transformer',
                                                                                                             'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.load_checkpoint': ( '5. text to semantic token '
                                                                                                            'modeling '
                                                                                                            'μp-copy1.html#tsartransformer.load_checkpoint',
                                                                                                            'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.load_model': ( '5. text to semantic token modeling '
                                                                                                       'μp-copy1.html#tsartransformer.load_model',
                                                                                                       'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.TSARTransformer.save_model': ( '5. text to semantic token modeling '
                                                                                                       'μp-copy1.html#tsartransformer.save_model',
                                                                                                       'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Tunables': ( '5. text to semantic token modeling '
                                                                                     'μp-copy1.html#tunables',
                                                                                     'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.Tunables.__post_init__': ( '5. text to semantic token modeling '
                                                                                                   'μp-copy1.html#tunables.__post_init__',
                                                                                                   'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.load_datasets': ( '5. text to semantic token modeling '
                                                                                          'μp-copy1.html#load_datasets',
                                                                                          'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.make_model': ( '5. text to semantic token modeling '
                                                                                       'μp-copy1.html#make_model',
                                                                                       'whisperspeech/t2s_up_tests.py'),
                                            'whisperspeech.t2s_up_tests.rand': ( '5. text to semantic token modeling μp-copy1.html#rand',
                                                                                 'whisperspeech/t2s_up_tests.py')},
            'whisperspeech.t2s_up_tests2': { 'whisperspeech.t2s_up_tests2.Decoder': ( '5. text to semantic token modeling '
                                                                                      'μp-copy2.html#decoder',
                                                                                      'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Decoder.__init__': ( '5. text to semantic token modeling '
                                                                                               'μp-copy2.html#decoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Decoder.forward': ( '5. text to semantic token modeling '
                                                                                              'μp-copy2.html#decoder.forward',
                                                                                              'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Encoder': ( '5. text to semantic token modeling '
                                                                                      'μp-copy2.html#encoder',
                                                                                      'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Encoder.__init__': ( '5. text to semantic token modeling '
                                                                                               'μp-copy2.html#encoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Encoder.forward': ( '5. text to semantic token modeling '
                                                                                              'μp-copy2.html#encoder.forward',
                                                                                              'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.SADataset': ( '5. text to semantic token modeling '
                                                                                        'μp-copy2.html#sadataset',
                                                                                        'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.SADataset.__getitem__': ( '5. text to semantic token modeling '
                                                                                                    'μp-copy2.html#sadataset.__getitem__',
                                                                                                    'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.SADataset.__init__': ( '5. text to semantic token modeling '
                                                                                                 'μp-copy2.html#sadataset.__init__',
                                                                                                 'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.SADataset.__len__': ( '5. text to semantic token modeling '
                                                                                                'μp-copy2.html#sadataset.__len__',
                                                                                                'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.SADataset.__repr__': ( '5. text to semantic token modeling '
                                                                                                 'μp-copy2.html#sadataset.__repr__',
                                                                                                 'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer': ( '5. text to semantic token modeling '
                                                                                              'μp-copy2.html#tsartransformer',
                                                                                              'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.__init__': ( '5. text to semantic token modeling '
                                                                                                       'μp-copy2.html#tsartransformer.__init__',
                                                                                                       'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.device': ( '5. text to semantic token modeling '
                                                                                                     'μp-copy2.html#tsartransformer.device',
                                                                                                     'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.ensure_tokenizer': ( '5. text to semantic token '
                                                                                                               'modeling '
                                                                                                               'μp-copy2.html#tsartransformer.ensure_tokenizer',
                                                                                                               'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.forward': ( '5. text to semantic token modeling '
                                                                                                      'μp-copy2.html#tsartransformer.forward',
                                                                                                      'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.generate': ( '5. text to semantic token modeling '
                                                                                                       'μp-copy2.html#tsartransformer.generate',
                                                                                                       'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.generate_batch': ( '5. text to semantic token '
                                                                                                             'modeling '
                                                                                                             'μp-copy2.html#tsartransformer.generate_batch',
                                                                                                             'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.init_transformer': ( '5. text to semantic token '
                                                                                                               'modeling '
                                                                                                               'μp-copy2.html#tsartransformer.init_transformer',
                                                                                                               'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.load_checkpoint': ( '5. text to semantic token '
                                                                                                              'modeling '
                                                                                                              'μp-copy2.html#tsartransformer.load_checkpoint',
                                                                                                              'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.load_model': ( '5. text to semantic token '
                                                                                                         'modeling '
                                                                                                         'μp-copy2.html#tsartransformer.load_model',
                                                                                                         'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.TSARTransformer.save_model': ( '5. text to semantic token '
                                                                                                         'modeling '
                                                                                                         'μp-copy2.html#tsartransformer.save_model',
                                                                                                         'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Tunables': ( '5. text to semantic token modeling '
                                                                                       'μp-copy2.html#tunables',
                                                                                       'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.Tunables.__post_init__': ( '5. text to semantic token modeling '
                                                                                                     'μp-copy2.html#tunables.__post_init__',
                                                                                                     'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.load_datasets': ( '5. text to semantic token modeling '
                                                                                            'μp-copy2.html#load_datasets',
                                                                                            'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.make_model': ( '5. text to semantic token modeling '
                                                                                         'μp-copy2.html#make_model',
                                                                                         'whisperspeech/t2s_up_tests2.py'),
                                             'whisperspeech.t2s_up_tests2.rand': ( '5. text to semantic token modeling μp-copy2.html#rand',
                                                                                   'whisperspeech/t2s_up_tests2.py')},
            'whisperspeech.t2s_up_tests3': { 'whisperspeech.t2s_up_tests3.CharTokenizer': ( '5. text to semantic token modeling μp '
                                                                                            'graphemes.html#chartokenizer',
                                                                                            'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.CharTokenizer.decode': ( '5. text to semantic token modeling μp '
                                                                                                   'graphemes.html#chartokenizer.decode',
                                                                                                   'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.CharTokenizer.encode': ( '5. text to semantic token modeling μp '
                                                                                                   'graphemes.html#chartokenizer.encode',
                                                                                                   'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Decoder': ( '5. text to semantic token modeling μp '
                                                                                      'graphemes.html#decoder',
                                                                                      'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Decoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                               'graphemes.html#decoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Decoder.forward': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes.html#decoder.forward',
                                                                                              'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Encoder': ( '5. text to semantic token modeling μp '
                                                                                      'graphemes.html#encoder',
                                                                                      'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Encoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                               'graphemes.html#encoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Encoder.forward': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes.html#encoder.forward',
                                                                                              'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.SADataset': ( '5. text to semantic token modeling μp '
                                                                                        'graphemes.html#sadataset',
                                                                                        'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.SADataset.__getitem__': ( '5. text to semantic token modeling μp '
                                                                                                    'graphemes.html#sadataset.__getitem__',
                                                                                                    'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.SADataset.__init__': ( '5. text to semantic token modeling μp '
                                                                                                 'graphemes.html#sadataset.__init__',
                                                                                                 'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.SADataset.__len__': ( '5. text to semantic token modeling μp '
                                                                                                'graphemes.html#sadataset.__len__',
                                                                                                'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.SADataset.__repr__': ( '5. text to semantic token modeling μp '
                                                                                                 'graphemes.html#sadataset.__repr__',
                                                                                                 'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes.html#tsartransformer',
                                                                                              'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.__init__': ( '5. text to semantic token modeling '
                                                                                                       'μp '
                                                                                                       'graphemes.html#tsartransformer.__init__',
                                                                                                       'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.device': ( '5. text to semantic token modeling '
                                                                                                     'μp '
                                                                                                     'graphemes.html#tsartransformer.device',
                                                                                                     'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.ensure_tokenizer': ( '5. text to semantic token '
                                                                                                               'modeling μp '
                                                                                                               'graphemes.html#tsartransformer.ensure_tokenizer',
                                                                                                               'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.forward': ( '5. text to semantic token modeling '
                                                                                                      'μp '
                                                                                                      'graphemes.html#tsartransformer.forward',
                                                                                                      'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.generate': ( '5. text to semantic token modeling '
                                                                                                       'μp '
                                                                                                       'graphemes.html#tsartransformer.generate',
                                                                                                       'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.generate_batch': ( '5. text to semantic token '
                                                                                                             'modeling μp '
                                                                                                             'graphemes.html#tsartransformer.generate_batch',
                                                                                                             'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.init_transformer': ( '5. text to semantic token '
                                                                                                               'modeling μp '
                                                                                                               'graphemes.html#tsartransformer.init_transformer',
                                                                                                               'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.load_checkpoint': ( '5. text to semantic token '
                                                                                                              'modeling μp '
                                                                                                              'graphemes.html#tsartransformer.load_checkpoint',
                                                                                                              'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.load_model': ( '5. text to semantic token '
                                                                                                         'modeling μp '
                                                                                                         'graphemes.html#tsartransformer.load_model',
                                                                                                         'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.TSARTransformer.save_model': ( '5. text to semantic token '
                                                                                                         'modeling μp '
                                                                                                         'graphemes.html#tsartransformer.save_model',
                                                                                                         'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Tunables': ( '5. text to semantic token modeling μp '
                                                                                       'graphemes.html#tunables',
                                                                                       'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.Tunables.__post_init__': ( '5. text to semantic token modeling '
                                                                                                     'μp '
                                                                                                     'graphemes.html#tunables.__post_init__',
                                                                                                     'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.load_datasets': ( '5. text to semantic token modeling μp '
                                                                                            'graphemes.html#load_datasets',
                                                                                            'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.make_model': ( '5. text to semantic token modeling μp '
                                                                                         'graphemes.html#make_model',
                                                                                         'whisperspeech/t2s_up_tests3.py'),
                                             'whisperspeech.t2s_up_tests3.rand': ( '5. text to semantic token modeling μp '
                                                                                   'graphemes.html#rand',
                                                                                   'whisperspeech/t2s_up_tests3.py')},
            'whisperspeech.t2s_up_tests4': { 'whisperspeech.t2s_up_tests4.CharTokenizer': ( '5. text to semantic token modeling μp '
                                                                                            'graphemes cleaned.html#chartokenizer',
                                                                                            'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.CharTokenizer.decode': ( '5. text to semantic token modeling μp '
                                                                                                   'graphemes '
                                                                                                   'cleaned.html#chartokenizer.decode',
                                                                                                   'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.CharTokenizer.encode': ( '5. text to semantic token modeling μp '
                                                                                                   'graphemes '
                                                                                                   'cleaned.html#chartokenizer.encode',
                                                                                                   'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Decoder': ( '5. text to semantic token modeling μp graphemes '
                                                                                      'cleaned.html#decoder',
                                                                                      'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Decoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                               'graphemes cleaned.html#decoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Decoder.forward': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes cleaned.html#decoder.forward',
                                                                                              'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Encoder': ( '5. text to semantic token modeling μp graphemes '
                                                                                      'cleaned.html#encoder',
                                                                                      'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Encoder.__init__': ( '5. text to semantic token modeling μp '
                                                                                               'graphemes cleaned.html#encoder.__init__',
                                                                                               'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Encoder.forward': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes cleaned.html#encoder.forward',
                                                                                              'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.SADataset': ( '5. text to semantic token modeling μp graphemes '
                                                                                        'cleaned.html#sadataset',
                                                                                        'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.SADataset.__getitem__': ( '5. text to semantic token modeling μp '
                                                                                                    'graphemes '
                                                                                                    'cleaned.html#sadataset.__getitem__',
                                                                                                    'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.SADataset.__init__': ( '5. text to semantic token modeling μp '
                                                                                                 'graphemes '
                                                                                                 'cleaned.html#sadataset.__init__',
                                                                                                 'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.SADataset.__len__': ( '5. text to semantic token modeling μp '
                                                                                                'graphemes cleaned.html#sadataset.__len__',
                                                                                                'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.SADataset.__repr__': ( '5. text to semantic token modeling μp '
                                                                                                 'graphemes '
                                                                                                 'cleaned.html#sadataset.__repr__',
                                                                                                 'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer': ( '5. text to semantic token modeling μp '
                                                                                              'graphemes cleaned.html#tsartransformer',
                                                                                              'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.__init__': ( '5. text to semantic token modeling '
                                                                                                       'μp graphemes '
                                                                                                       'cleaned.html#tsartransformer.__init__',
                                                                                                       'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.device': ( '5. text to semantic token modeling '
                                                                                                     'μp graphemes '
                                                                                                     'cleaned.html#tsartransformer.device',
                                                                                                     'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.ensure_tokenizer': ( '5. text to semantic token '
                                                                                                               'modeling μp graphemes '
                                                                                                               'cleaned.html#tsartransformer.ensure_tokenizer',
                                                                                                               'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.forward': ( '5. text to semantic token modeling '
                                                                                                      'μp graphemes '
                                                                                                      'cleaned.html#tsartransformer.forward',
                                                                                                      'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.generate': ( '5. text to semantic token modeling '
                                                                                                       'μp graphemes '
                                                                                                       'cleaned.html#tsartransformer.generate',
                                                                                                       'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.generate_batch': ( '5. text to semantic token '
                                                                                                             'modeling μp graphemes '
                                                                                                             'cleaned.html#tsartransformer.generate_batch',
                                                                                                             'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.init_transformer': ( '5. text to semantic token '
                                                                                                               'modeling μp graphemes '
                                                                                                               'cleaned.html#tsartransformer.init_transformer',
                                                                                                               'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.load_checkpoint': ( '5. text to semantic token '
                                                                                                              'modeling μp graphemes '
                                                                                                              'cleaned.html#tsartransformer.load_checkpoint',
                                                                                                              'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.load_model': ( '5. text to semantic token '
                                                                                                         'modeling μp graphemes '
                                                                                                         'cleaned.html#tsartransformer.load_model',
                                                                                                         'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.TSARTransformer.save_model': ( '5. text to semantic token '
                                                                                                         'modeling μp graphemes '
                                                                                                         'cleaned.html#tsartransformer.save_model',
                                                                                                         'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Tunables': ( '5. text to semantic token modeling μp graphemes '
                                                                                       'cleaned.html#tunables',
                                                                                       'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.Tunables.__post_init__': ( '5. text to semantic token modeling '
                                                                                                     'μp graphemes '
                                                                                                     'cleaned.html#tunables.__post_init__',
                                                                                                     'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.load_datasets': ( '5. text to semantic token modeling μp '
                                                                                            'graphemes cleaned.html#load_datasets',
                                                                                            'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.make_model': ( '5. text to semantic token modeling μp graphemes '
                                                                                         'cleaned.html#make_model',
                                                                                         'whisperspeech/t2s_up_tests4.py'),
                                             'whisperspeech.t2s_up_tests4.rand': ( '5. text to semantic token modeling μp graphemes '
                                                                                   'cleaned.html#rand',
                                                                                   'whisperspeech/t2s_up_tests4.py')},
            'whisperspeech.t2s_up_wds': { 'whisperspeech.t2s_up_wds.CharTokenizer': ( '5b. text to semantic token '
                                                                                      'modeling.html#chartokenizer',
                                                                                      'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.CharTokenizer.decode': ( '5b. text to semantic token '
                                                                                             'modeling.html#chartokenizer.decode',
                                                                                             'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.CharTokenizer.encode': ( '5b. text to semantic token '
                                                                                             'modeling.html#chartokenizer.encode',
                                                                                             'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Decoder': ( '5b. text to semantic token modeling.html#decoder',
                                                                                'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Decoder.__init__': ( '5b. text to semantic token '
                                                                                         'modeling.html#decoder.__init__',
                                                                                         'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Decoder.forward': ( '5b. text to semantic token '
                                                                                        'modeling.html#decoder.forward',
                                                                                        'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.EmbeddingProjector': ( '5b. text to semantic token '
                                                                                           'modeling.html#embeddingprojector',
                                                                                           'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Encoder': ( '5b. text to semantic token modeling.html#encoder',
                                                                                'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Encoder.__init__': ( '5b. text to semantic token '
                                                                                         'modeling.html#encoder.__init__',
                                                                                         'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Encoder.forward': ( '5b. text to semantic token '
                                                                                        'modeling.html#encoder.forward',
                                                                                        'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer': ( '5b. text to semantic token '
                                                                                        'modeling.html#tsartransformer',
                                                                                        'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.__init__': ( '5b. text to semantic token '
                                                                                                 'modeling.html#tsartransformer.__init__',
                                                                                                 'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.device': ( '5b. text to semantic token '
                                                                                               'modeling.html#tsartransformer.device',
                                                                                               'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.ensure_tokenizer': ( '5b. text to semantic token '
                                                                                                         'modeling.html#tsartransformer.ensure_tokenizer',
                                                                                                         'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.forward': ( '5b. text to semantic token '
                                                                                                'modeling.html#tsartransformer.forward',
                                                                                                'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.generate': ( '5b. text to semantic token '
                                                                                                 'modeling.html#tsartransformer.generate',
                                                                                                 'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.generate_batch': ( '5b. text to semantic token '
                                                                                                       'modeling.html#tsartransformer.generate_batch',
                                                                                                       'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.init_transformer': ( '5b. text to semantic token '
                                                                                                         'modeling.html#tsartransformer.init_transformer',
                                                                                                         'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.load_checkpoint': ( '5b. text to semantic token '
                                                                                                        'modeling.html#tsartransformer.load_checkpoint',
                                                                                                        'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.load_frozen_semantic_embeddings': ( '5b. text to '
                                                                                                                        'semantic token '
                                                                                                                        'modeling.html#tsartransformer.load_frozen_semantic_embeddings',
                                                                                                                        'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.load_model': ( '5b. text to semantic token '
                                                                                                   'modeling.html#tsartransformer.load_model',
                                                                                                   'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.save_model': ( '5b. text to semantic token '
                                                                                                   'modeling.html#tsartransformer.save_model',
                                                                                                   'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.TSARTransformer.setup': ( '5b. text to semantic token '
                                                                                              'modeling.html#tsartransformer.setup',
                                                                                              'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Tunables': ( '5b. text to semantic token modeling.html#tunables',
                                                                                 'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.Tunables.__post_init__': ( '5b. text to semantic token '
                                                                                               'modeling.html#tunables.__post_init__',
                                                                                               'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds._make_model': ( '5b. text to semantic token modeling.html#_make_model',
                                                                                    'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.ar_padder': ( '5b. text to semantic token modeling.html#ar_padder',
                                                                                  'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.build_speaker_map': ( '5b. text to semantic token '
                                                                                          'modeling.html#build_speaker_map',
                                                                                          'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.char_per_seconder': ( '5b. text to semantic token '
                                                                                          'modeling.html#char_per_seconder',
                                                                                          'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.load_datasets': ( '5b. text to semantic token '
                                                                                      'modeling.html#load_datasets',
                                                                                      'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.make_model': ( '5b. text to semantic token modeling.html#make_model',
                                                                                   'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.rand': ( '5b. text to semantic token modeling.html#rand',
                                                                             'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.speaker_id_extractor': ( '5b. text to semantic token '
                                                                                             'modeling.html#speaker_id_extractor',
                                                                                             'whisperspeech/t2s_up_wds.py'),
                                          'whisperspeech.t2s_up_wds.tokenizer': ( '5b. text to semantic token modeling.html#tokenizer',
                                                                                  'whisperspeech/t2s_up_wds.py')},
            'whisperspeech.train': { 'whisperspeech.train.SimpleVisual': ('b1. training.html#simplevisual', 'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.__init__': ( 'b1. training.html#simplevisual.__init__',
                                                                                    'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.add_data': ( 'b1. training.html#simplevisual.add_data',
                                                                                    'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.add_table_row': ( 'b1. training.html#simplevisual.add_table_row',
                                                                                         'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.hide': ( 'b1. training.html#simplevisual.hide',
                                                                                'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.on_iter': ( 'b1. training.html#simplevisual.on_iter',
                                                                                   'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.plot': ( 'b1. training.html#simplevisual.plot',
                                                                                'whisperspeech/train.py'),
                                     'whisperspeech.train.SimpleVisual.show': ( 'b1. training.html#simplevisual.show',
                                                                                'whisperspeech/train.py'),
                                     'whisperspeech.train.train': ('b1. training.html#train', 'whisperspeech/train.py'),
                                     'whisperspeech.train.validate': ('b1. training.html#validate', 'whisperspeech/train.py')},
            'whisperspeech.train_multi': { 'whisperspeech.train_multi.TrainingTask': ( 'b2. training (lightning).html#trainingtask',
                                                                                       'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.__init__': ( 'b2. training '
                                                                                                '(lightning).html#trainingtask.__init__',
                                                                                                'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.configure_optimizers': ( 'b2. training '
                                                                                                            '(lightning).html#trainingtask.configure_optimizers',
                                                                                                            'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.on_fit_start': ( 'b2. training '
                                                                                                    '(lightning).html#trainingtask.on_fit_start',
                                                                                                    'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.on_validation_epoch_end': ( 'b2. training '
                                                                                                               '(lightning).html#trainingtask.on_validation_epoch_end',
                                                                                                               'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.test_step': ( 'b2. training '
                                                                                                 '(lightning).html#trainingtask.test_step',
                                                                                                 'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.training_step': ( 'b2. training '
                                                                                                     '(lightning).html#trainingtask.training_step',
                                                                                                     'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.TrainingTask.validation_step': ( 'b2. training '
                                                                                                       '(lightning).html#trainingtask.validation_step',
                                                                                                       'whisperspeech/train_multi.py'),
                                           'whisperspeech.train_multi.parse_and_call': ( 'b2. training (lightning).html#parse_and_call',
                                                                                         'whisperspeech/train_multi.py')},
            'whisperspeech.vad': { 'whisperspeech.vad.extract_segments': ( '1b. voice activity detection.html#extract_segments',
                                                                           'whisperspeech/vad.py'),
                                   'whisperspeech.vad.fix_dots_in_names': ( '1b. voice activity detection.html#fix_dots_in_names',
                                                                            'whisperspeech/vad.py'),
                                   'whisperspeech.vad.flac_to_vad_name': ( '1b. voice activity detection.html#flac_to_vad_name',
                                                                           'whisperspeech/vad.py'),
                                   'whisperspeech.vad.load_dataset': ( '1b. voice activity detection.html#load_dataset',
                                                                       'whisperspeech/vad.py'),
                                   'whisperspeech.vad.process_shard': ( '1b. voice activity detection.html#process_shard',
                                                                        'whisperspeech/vad.py'),
                                   'whisperspeech.vad.segment_audio': ( '1b. voice activity detection.html#segment_audio',
                                                                        'whisperspeech/vad.py')},
            'whisperspeech.verify_wds': { 'whisperspeech.verify_wds.process_shard': ( '0. verify webdataset archives.html#process_shard',
                                                                                      'whisperspeech/verify_wds.py')},
            'whisperspeech.vq_stoks': { 'whisperspeech.vq_stoks.RQBottleneckTransformer': ( '2b. whisper quantization (semantic token) '
                                                                                            'model.html#rqbottlenecktransformer',
                                                                                            'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.__init__': ( '2b. whisper quantization (semantic '
                                                                                                     'token) '
                                                                                                     'model.html#rqbottlenecktransformer.__init__',
                                                                                                     'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.decode_text': ( '2b. whisper quantization '
                                                                                                        '(semantic token) '
                                                                                                        'model.html#rqbottlenecktransformer.decode_text',
                                                                                                        'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.dequantize': ( '2b. whisper quantization (semantic '
                                                                                                       'token) '
                                                                                                       'model.html#rqbottlenecktransformer.dequantize',
                                                                                                       'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.device': ( '2b. whisper quantization (semantic '
                                                                                                   'token) '
                                                                                                   'model.html#rqbottlenecktransformer.device',
                                                                                                   'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.downsample_embeddings': ( '2b. whisper '
                                                                                                                  'quantization (semantic '
                                                                                                                  'token) '
                                                                                                                  'model.html#rqbottlenecktransformer.downsample_embeddings',
                                                                                                                  'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.encode_audio': ( '2b. whisper quantization '
                                                                                                         '(semantic token) '
                                                                                                         'model.html#rqbottlenecktransformer.encode_audio',
                                                                                                         'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.encode_mel': ( '2b. whisper quantization (semantic '
                                                                                                       'token) '
                                                                                                       'model.html#rqbottlenecktransformer.encode_mel',
                                                                                                       'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.ensure_whisper': ( '2b. whisper quantization '
                                                                                                           '(semantic token) '
                                                                                                           'model.html#rqbottlenecktransformer.ensure_whisper',
                                                                                                           'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.extract_teacher': ( '2b. whisper quantization '
                                                                                                            '(semantic token) '
                                                                                                            'model.html#rqbottlenecktransformer.extract_teacher',
                                                                                                            'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.forward': ( '2b. whisper quantization (semantic '
                                                                                                    'token) '
                                                                                                    'model.html#rqbottlenecktransformer.forward',
                                                                                                    'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.get_metrics': ( '2b. whisper quantization '
                                                                                                        '(semantic token) '
                                                                                                        'model.html#rqbottlenecktransformer.get_metrics',
                                                                                                        'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.init_transformer': ( '2b. whisper quantization '
                                                                                                             '(semantic token) '
                                                                                                             'model.html#rqbottlenecktransformer.init_transformer',
                                                                                                             'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.load_checkpoint': ( '2b. whisper quantization '
                                                                                                            '(semantic token) '
                                                                                                            'model.html#rqbottlenecktransformer.load_checkpoint',
                                                                                                            'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.load_model': ( '2b. whisper quantization (semantic '
                                                                                                       'token) '
                                                                                                       'model.html#rqbottlenecktransformer.load_model',
                                                                                                       'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.quantize': ( '2b. whisper quantization (semantic '
                                                                                                     'token) '
                                                                                                     'model.html#rqbottlenecktransformer.quantize',
                                                                                                     'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.save_model': ( '2b. whisper quantization (semantic '
                                                                                                       'token) '
                                                                                                       'model.html#rqbottlenecktransformer.save_model',
                                                                                                       'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.RQBottleneckTransformer.setup': ( '2b. whisper quantization (semantic '
                                                                                                  'token) '
                                                                                                  'model.html#rqbottlenecktransformer.setup',
                                                                                                  'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.Tunables': ( '2b. whisper quantization (semantic token) '
                                                                             'model.html#tunables',
                                                                             'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.Tunables.__post_init__': ( '2b. whisper quantization (semantic token) '
                                                                                           'model.html#tunables.__post_init__',
                                                                                           'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.Tunables.upgrade': ( '2b. whisper quantization (semantic token) '
                                                                                     'model.html#tunables.upgrade',
                                                                                     'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.add_masks': ( '2b. whisper quantization (semantic token) '
                                                                              'model.html#add_masks',
                                                                              'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.derived_dataset': ( '2b. whisper quantization (semantic token) '
                                                                                    'model.html#derived_dataset',
                                                                                    'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.load_datasets': ( '2b. whisper quantization (semantic token) '
                                                                                  'model.html#load_datasets',
                                                                                  'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.logrand': ( '2b. whisper quantization (semantic token) model.html#logrand',
                                                                            'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.make_model': ( '2b. whisper quantization (semantic token) '
                                                                               'model.html#make_model',
                                                                               'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.merge_in': ( '2b. whisper quantization (semantic token) '
                                                                             'model.html#merge_in',
                                                                             'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.rand': ( '2b. whisper quantization (semantic token) model.html#rand',
                                                                         'whisperspeech/vq_stoks.py'),
                                        'whisperspeech.vq_stoks.tokenize_text': ( '2b. whisper quantization (semantic token) '
                                                                                  'model.html#tokenize_text',
                                                                                  'whisperspeech/vq_stoks.py')},
            'whisperspeech.vq_stoks_old': { 'whisperspeech.vq_stoks_old.RQBottleneckTransformer': ( '2a. vq semantic token extraction '
                                                                                                    'model-copy1.html#rqbottlenecktransformer',
                                                                                                    'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.__init__': ( '2a. vq semantic token '
                                                                                                             'extraction '
                                                                                                             'model-copy1.html#rqbottlenecktransformer.__init__',
                                                                                                             'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.decode_text': ( '2a. vq semantic token '
                                                                                                                'extraction '
                                                                                                                'model-copy1.html#rqbottlenecktransformer.decode_text',
                                                                                                                'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.dequantize': ( '2a. vq semantic token '
                                                                                                               'extraction '
                                                                                                               'model-copy1.html#rqbottlenecktransformer.dequantize',
                                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.downsample_embeddings': ( '2a. vq semantic '
                                                                                                                          'token '
                                                                                                                          'extraction '
                                                                                                                          'model-copy1.html#rqbottlenecktransformer.downsample_embeddings',
                                                                                                                          'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.encode_audio': ( '2a. vq semantic token '
                                                                                                                 'extraction '
                                                                                                                 'model-copy1.html#rqbottlenecktransformer.encode_audio',
                                                                                                                 'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.encode_mel': ( '2a. vq semantic token '
                                                                                                               'extraction '
                                                                                                               'model-copy1.html#rqbottlenecktransformer.encode_mel',
                                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.ensure_whisper': ( '2a. vq semantic token '
                                                                                                                   'extraction '
                                                                                                                   'model-copy1.html#rqbottlenecktransformer.ensure_whisper',
                                                                                                                   'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.extract_teacher': ( '2a. vq semantic token '
                                                                                                                    'extraction '
                                                                                                                    'model-copy1.html#rqbottlenecktransformer.extract_teacher',
                                                                                                                    'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.forward': ( '2a. vq semantic token '
                                                                                                            'extraction '
                                                                                                            'model-copy1.html#rqbottlenecktransformer.forward',
                                                                                                            'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.init_transformer': ( '2a. vq semantic '
                                                                                                                     'token extraction '
                                                                                                                     'model-copy1.html#rqbottlenecktransformer.init_transformer',
                                                                                                                     'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.load_model': ( '2a. vq semantic token '
                                                                                                               'extraction '
                                                                                                               'model-copy1.html#rqbottlenecktransformer.load_model',
                                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.quantize': ( '2a. vq semantic token '
                                                                                                             'extraction '
                                                                                                             'model-copy1.html#rqbottlenecktransformer.quantize',
                                                                                                             'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.reset_stats': ( '2a. vq semantic token '
                                                                                                                'extraction '
                                                                                                                'model-copy1.html#rqbottlenecktransformer.reset_stats',
                                                                                                                'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQBottleneckTransformer.save_model': ( '2a. vq semantic token '
                                                                                                               'extraction '
                                                                                                               'model-copy1.html#rqbottlenecktransformer.save_model',
                                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual': ( '2a. vq semantic token extraction '
                                                                                     'model-copy1.html#rqvisual',
                                                                                     'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.__init__': ( '2a. vq semantic token extraction '
                                                                                              'model-copy1.html#rqvisual.__init__',
                                                                                              'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.add_data': ( '2a. vq semantic token extraction '
                                                                                              'model-copy1.html#rqvisual.add_data',
                                                                                              'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.add_table_row': ( '2a. vq semantic token extraction '
                                                                                                   'model-copy1.html#rqvisual.add_table_row',
                                                                                                   'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.hide': ( '2a. vq semantic token extraction '
                                                                                          'model-copy1.html#rqvisual.hide',
                                                                                          'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.on_iter': ( '2a. vq semantic token extraction '
                                                                                             'model-copy1.html#rqvisual.on_iter',
                                                                                             'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.plot': ( '2a. vq semantic token extraction '
                                                                                          'model-copy1.html#rqvisual.plot',
                                                                                          'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.RQVisual.show': ( '2a. vq semantic token extraction '
                                                                                          'model-copy1.html#rqvisual.show',
                                                                                          'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset': ( '2a. vq semantic token extraction '
                                                                                      'model-copy1.html#sadataset',
                                                                                      'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.__init__': ( '2a. vq semantic token extraction '
                                                                                               'model-copy1.html#sadataset.__init__',
                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.__iter__': ( '2a. vq semantic token extraction '
                                                                                               'model-copy1.html#sadataset.__iter__',
                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.__len__': ( '2a. vq semantic token extraction '
                                                                                              'model-copy1.html#sadataset.__len__',
                                                                                              'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.__repr__': ( '2a. vq semantic token extraction '
                                                                                               'model-copy1.html#sadataset.__repr__',
                                                                                               'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.chunk_iterator': ( '2a. vq semantic token extraction '
                                                                                                     'model-copy1.html#sadataset.chunk_iterator',
                                                                                                     'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.get_subset': ( '2a. vq semantic token extraction '
                                                                                                 'model-copy1.html#sadataset.get_subset',
                                                                                                 'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.hours': ( '2a. vq semantic token extraction '
                                                                                            'model-copy1.html#sadataset.hours',
                                                                                            'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.load_audio': ( '2a. vq semantic token extraction '
                                                                                                 'model-copy1.html#sadataset.load_audio',
                                                                                                 'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.transform_audio': ( '2a. vq semantic token extraction '
                                                                                                      'model-copy1.html#sadataset.transform_audio',
                                                                                                      'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.SADataset.transform_ttoks': ( '2a. vq semantic token extraction '
                                                                                                      'model-copy1.html#sadataset.transform_ttoks',
                                                                                                      'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.Tunables': ( '2a. vq semantic token extraction '
                                                                                     'model-copy1.html#tunables',
                                                                                     'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.Tunables.__post_init__': ( '2a. vq semantic token extraction '
                                                                                                   'model-copy1.html#tunables.__post_init__',
                                                                                                   'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.Tunables.upgrade': ( '2a. vq semantic token extraction '
                                                                                             'model-copy1.html#tunables.upgrade',
                                                                                             'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.load_datasets': ( '2a. vq semantic token extraction '
                                                                                          'model-copy1.html#load_datasets',
                                                                                          'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.make_model': ( '2a. vq semantic token extraction '
                                                                                       'model-copy1.html#make_model',
                                                                                       'whisperspeech/vq_stoks_old.py'),
                                            'whisperspeech.vq_stoks_old.rand': ( '2a. vq semantic token extraction model-copy1.html#rand',
                                                                                 'whisperspeech/vq_stoks_old.py')},
            'whisperspeech.wer_metrics': { 'whisperspeech.wer_metrics.DfBuilder': ( 'c. word error rate metrics.html#dfbuilder',
                                                                                    'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.DfBuilder.__init__': ( 'c. word error rate '
                                                                                             'metrics.html#dfbuilder.__init__',
                                                                                             'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.DfBuilder.df': ( 'c. word error rate metrics.html#dfbuilder.df',
                                                                                       'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.DfBuilder.push': ( 'c. word error rate metrics.html#dfbuilder.push',
                                                                                         'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.WERStats': ( 'c. word error rate metrics.html#werstats',
                                                                                   'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.WERStats.__init__': ( 'c. word error rate '
                                                                                            'metrics.html#werstats.__init__',
                                                                                            'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.WERStats.push_sample': ( 'c. word error rate '
                                                                                               'metrics.html#werstats.push_sample',
                                                                                               'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.librispeech_data': ( 'c. word error rate '
                                                                                           'metrics.html#librispeech_data',
                                                                                           'whisperspeech/wer_metrics.py'),
                                           'whisperspeech.wer_metrics.whisper_normalize': ( 'c. word error rate '
                                                                                            'metrics.html#whisper_normalize',
                                                                                            'whisperspeech/wer_metrics.py')},
            'whisperspeech.wh_transcribe': { 'whisperspeech.wh_transcribe.chunk_merger': ( '2a. whisper quantization dataset '
                                                                                           'preparation.html#chunk_merger',
                                                                                           'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.flac_to_txt_name': ( '2a. whisper quantization dataset '
                                                                                               'preparation.html#flac_to_txt_name',
                                                                                               'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.merge_in': ( '2a. whisper quantization dataset '
                                                                                       'preparation.html#merge_in',
                                                                                       'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.process_shard': ( '2a. whisper quantization dataset '
                                                                                            'preparation.html#process_shard',
                                                                                            'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.random_cutter': ( '2a. whisper quantization dataset '
                                                                                            'preparation.html#random_cutter',
                                                                                            'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.split_to_chunks': ( '2a. whisper quantization dataset '
                                                                                              'preparation.html#split_to_chunks',
                                                                                              'whisperspeech/wh_transcribe.py'),
                                             'whisperspeech.wh_transcribe.wds_compose': ( '2a. whisper quantization dataset '
                                                                                          'preparation.html#wds_compose',
                                                                                          'whisperspeech/wh_transcribe.py')},
            'whisperspeech.wx_transcribe': { 'whisperspeech.wx_transcribe.Transcriber': ( '4. whisperx medium semantic and text token '
                                                                                          'extraction.html#transcriber',
                                                                                          'whisperspeech/wx_transcribe.py'),
                                             'whisperspeech.wx_transcribe.Transcriber.__init__': ( '4. whisperx medium semantic and text '
                                                                                                   'token '
                                                                                                   'extraction.html#transcriber.__init__',
                                                                                                   'whisperspeech/wx_transcribe.py'),
                                             'whisperspeech.wx_transcribe.Transcriber.transcribe': ( '4. whisperx medium semantic and text '
                                                                                                     'token '
                                                                                                     'extraction.html#transcriber.transcribe',
                                                                                                     'whisperspeech/wx_transcribe.py')}}}
